@@ -13,15 +13,20 @@ local(@mods, %miniserv, $_, @rv, %acl);
 &get_miniserv_config(\%miniserv);
 open(PWFILE, $miniserv{'userfile'});
 while(<PWFILE>) {
-	if (/^([^:\s]+):([^:\s]+)(:(\d+))?(:(.*))?/) {
+	s/\r|\n//g;
+	local @user = split(/:/, $_);
+	if (@user) {
 		local(%user);
-		$user{'name'} = $1;
-		$user{'pass'} = $2;
-		$user{'sync'} = $4 if ($3);
-		$user{'cert'} = $6 if ($5);
-		$user{'modules'} = $acl{$1};
-		$user{'lang'} = $gconfig{"lang_$1"};
-		$user{'notabs'} = $gconfig{"notabs_$1"};
+		$user{'name'} = $user[0];
+		$user{'pass'} = $user[1];
+		$user{'sync'} = $user[2];
+		$user{'cert'} = $user[3];
+		if ($user[4] =~ /^(allow|deny)\s+(.*)/) {
+			$user{$1} = $2;
+			}
+		$user{'modules'} = $acl{$user[0]};
+		$user{'lang'} = $gconfig{"lang_$user[0]"};
+		$user{'notabs'} = $gconfig{"notabs_$user[0]"};
 		push(@rv, \%user);
 		}
 	}
@@ -61,7 +66,9 @@ local(%user, %miniserv, @mods);
 %user = %{$_[0]};
 &get_miniserv_config(\%miniserv);
 open(PWFILE, ">> $miniserv{'userfile'}");
-print PWFILE "$user{'name'}:$user{'pass'}:$user{'sync'}:$user{'cert'}\n";
+print PWFILE "$user{'name'}:$user{'pass'}:$user{'sync'}:$user{'cert'}:",
+	$user{'allow'} ? "allow $user{'allow'}" :
+	$user{'deny'} ? "deny $user{'deny'}" : "","\n";
 close(PWFILE);
 @mods = &list_modules();
 open(ACL, ">> ".&acl_filename());
@@ -104,7 +111,10 @@ close(PWFILE);
 open(PWFILE, "> $miniserv{'userfile'}");
 foreach (@pwfile) {
 	if (/^([^:\s]+):([^:\s]+)/ && $1 eq $_[0]) {
-		print PWFILE "$user{'name'}:$user{'pass'}:$user{'sync'}:$user{'cert'}\n";
+		print PWFILE "$user{'name'}:$user{'pass'}:",
+			     "$user{'sync'}:$user{'cert'}:",
+			$user{'allow'} ? "allow $user{'allow'}" :
+			$user{'deny'} ? "deny $user{'deny'}" : "","\n";
 		}
 	else { print PWFILE $_; }
 	}
