@@ -16,15 +16,15 @@ foreach $u (&list_users()) {
 	}
 print "</select></td>\n";
 
-print "<td valign=top rowspan=4><b>$text{'acl_mods'}</b></td> ",
-      "<td valign=top rowspan=4>\n";
+print "<td valign=top rowspan=3><b>$text{'acl_mods'}</b></td> ",
+      "<td valign=top rowspan=3>\n";
 printf "<input type=radio name=mode value=0 %s> %s&nbsp;\n",
 	$o->{'mode'} == 0 ? 'checked' : '', $text{'acl_all'};
 printf "<input type=radio name=mode value=1 %s> %s<br>\n",
 	$o->{'mode'} == 1 ? 'checked' : '', $text{'acl_own'};
 printf "<input type=radio name=mode value=2 %s> %s<br>\n",
 	$o->{'mode'} == 2 ? 'checked' : '', $text{'acl_sel'};
-print "&nbsp;&nbsp;&nbsp;<select name=mods multiple size=6>\n";
+print "&nbsp;&nbsp;&nbsp;<select name=mods multiple size=5>\n";
 map { $mcan{$_}++ } split(/\s+/, $o->{'mods'});
 foreach $m (&list_modules()) {
 	%minfo = &get_module_info($m);
@@ -48,9 +48,15 @@ printf "<input type=radio name=delete value=0 %s> $text{'no'}</td> </tr>\n",
 print "<tr> <td><b>$text{'acl_rename'}</b></td> <td>\n";
 printf "<input type=radio name=rename value=1 %s> $text{'yes'}\n",
 	$o->{'rename'} ? 'checked' : '';
-printf "<input type=radio name=rename value=0 %s> $text{'no'}</td> </tr>\n",
+printf "<input type=radio name=rename value=0 %s> $text{'no'}</td>\n",
 	$o->{'rename'} ? '' : 'checked';
 
+print "<td><b>$text{'acl_acl'}</b></td> <td>\n";
+printf "<input type=radio name=acl value=1 %s> $text{'yes'}\n",
+	$o->{'acl'} ? 'checked' : '';
+printf "<input type=radio name=acl value=0 %s> $text{'no'}</td> </tr>\n",
+	$o->{'acl'} ? '' : 'checked';
+
 print "<tr> <td><b>$text{'acl_cert'}</b></td> <td>\n";
 printf "<input type=radio name=cert value=1 %s> $text{'yes'}\n",
 	$o->{'cert'} ? 'checked' : '';
@@ -62,6 +68,18 @@ printf "<input type=radio name=others value=1 %s> $text{'yes'}\n",
 	$o->{'others'} ? 'checked' : '';
 printf "<input type=radio name=others value=0 %s> $text{'no'}</td> </tr>\n",
 	$o->{'others'} ? '' : 'checked';
+
+print "<tr> <td><b>$text{'acl_chcert'}</b></td> <td>\n";
+printf "<input type=radio name=chcert value=1 %s> $text{'yes'}\n",
+	$o->{'chcert'} ? 'checked' : '';
+printf "<input type=radio name=chcert value=0 %s> $text{'no'}</td>\n",
+	$o->{'chcert'} ? '' : 'checked';
+
+print "<td><b>$text{'acl_lang'}</b></td> <td>\n";
+printf "<input type=radio name=lang value=1 %s> $text{'yes'}\n",
+	$o->{'lang'} ? 'checked' : '';
+printf "<input type=radio name=lang value=0 %s> $text{'no'}</td> </tr>\n",
+	$o->{'lang'} ? '' : 'checked';
 }
 
 # acl_security_save(&options)
@@ -82,7 +100,10 @@ $_[0]->{'mods'} = $in{'mode'} == 2 ? join(" ", split(/\0/, $in{'mods'}))
 $_[0]->{'create'} = $in{'create'};
 $_[0]->{'delete'} = $in{'delete'};
 $_[0]->{'rename'} = $in{'rename'};
+$_[0]->{'acl'} = $in{'acl'};
 $_[0]->{'others'} = $in{'others'};
 $_[0]->{'cert'} = $in{'cert'};
+$_[0]->{'chcert'} = $in{'chcert'};
+$_[0]->{'lang'} = $in{'lang'};
 }
 
