@@ -94,100 +94,100 @@ return ();
 sub edit_MaxClients
 {
 return (1,
-	"Maximum concurrent requests",
-	&opt_input($_[0]->{'value'}, "MaxClients", "Default", 4));
+	$text{'core_0'},
+	&opt_input($_[0]->{'value'}, "MaxClients", $text{'core_12'}, 4));
 }
 sub save_MaxClients
 {
 return &parse_opt("MaxClients", '^\d+$',
-		  "Maximum concurrent requests must be an integer");
+		  $text{'core_6'});
 }
 
 sub edit_MaxKeepAliveRequests
 {
 return (1,
-	"Maximum keepalives per connection",
-	&opt_input($_[0]->{'value'}, "MaxKeepAliveRequests", "Default", 4));
+	$text{'core_1'},
+	&opt_input($_[0]->{'value'}, "MaxKeepAliveRequests", $text{'core_13'}, 4));
 }
 sub save_MaxKeepAliveRequests
 {
 return &parse_opt("MaxKeepAliveRequests", '^\d+$',
-		  "Maximum keepalives per connection must be an integer");
+		  $text{'core_7'});
 }
 
 sub edit_MaxRequestsPerChild
 {
 return (1,
-	"Maximum requests per server process",
-	&opt_input($_[0]->{'value'}, "MaxRequestsPerChild", "Default", 5));
+	$text{'core_2'},
+	&opt_input($_[0]->{'value'}, "MaxRequestsPerChild", $text{'core_14'}, 5));
 }
 sub save_MaxRequestsPerChild
 {
 return &parse_opt("MaxRequestsPerChild", '^\d+$',
-		  "Maximum requests per server process must be an integer");
+		  $text{'core_8'});
 }
 
 sub edit_MinSpareServers
 {
 return (1,
-	"Minimum spare server processes",
-	&opt_input($_[0]->{'value'},"MinSpareServers","Default", 4));
+	$text{'core_3'},
+	&opt_input($_[0]->{'value'},"MinSpareServers",$text{'core_15'}, 4));
 }
 sub save_MinSpareServers
 {
 return &parse_opt("MinSpareServers", '^\d+$',
-		  "Minimum spare server processes must be an integer");
+		  $text{'core_9'});
 }
 
 sub edit_MaxSpareServers
 {
 return (1,
-	"Maximum spare server processes",
-	&opt_input($_[0]->{'value'},"MaxSpareServers","Default", 4));
+	$text{'core_4'},
+	&opt_input($_[0]->{'value'},"MaxSpareServers",$text{'core_16'}, 4));
 }
 sub save_MaxSpareServers
 {
 return &parse_opt("MaxSpareServers", '^\d+$',
-		  "Maximum spare server processes must be an integer");
+		  $text{'core_10'});
 }
 
 sub edit_StartServers
 {
 return (1,
-	"Initial server processes",
-	&opt_input($_[0]->{'value'}, "StartServers", "Default", 4));
+	$text{'core_5'},
+	&opt_input($_[0]->{'value'}, "StartServers", $text{'core_17'}, 4));
 }
 sub save_StartServers
 {
 return &parse_opt("StartServers", '^\d+$',
-		  "Initial server processes must be an integer");
+		  $text{'core_11'});
 }
 
 sub edit_RLimitCPU
 {
-return &rlimit_input("RLimitCPU", "CPU resource limit", $_[0]);
+return &rlimit_input("RLimitCPU", $text{'core_18'}, $_[0]);
 }
 sub save_RLimitCPU
 {
-return &parse_rlimit("RLimitCPU", "CPU resource limit");
+return &parse_rlimit("RLimitCPU", $text{'core_21'});
 }
 
 sub edit_RLimitMEM
 {
-return &rlimit_input("RLimitMEM", "Memory resource limit", $_[0]);
+return &rlimit_input("RLimitMEM", $text{'core_19'}, $_[0]);
 }
 sub save_RLimitMEM
 {
-return &parse_rlimit("RLimitMEM", "memory resource limit");
+return &parse_rlimit("RLimitMEM", $text{'core_22'});
 }
 
 sub edit_RLimitNPROC
 {
-return &rlimit_input("RLimitNPROC", "Process limit", $_[0]);
+return &rlimit_input("RLimitNPROC", $text{'core_20'}, $_[0]);
 }
 sub save_RLimitNPROC
 {
-return &parse_rlimit("RLimitNPROC", "process limit");
+return &parse_rlimit("RLimitNPROC", $text{'core_23'});
 }
 
 # rlimit_input(name, desc, value)
@@ -199,13 +199,13 @@ $rv = sprintf "<input type=radio name=$_[0]_mode value=0 %s> Default<br>\n",
 	@v ? "" : "checked";
 $rv .= sprintf "<input type=radio name=$_[0]_mode value=1 %s>\n",
 	@v == 1 ? "checked" : "";
-$rv .= sprintf "Soft limit <input name=$_[0]_soft1 size=5 value=\"%s\"><br>\n",
+$rv .= sprintf "$text{'core_24'}<input name=$_[0]_soft1 size=5 value=\"%s\"><br>\n",
 	@v == 1 ? $v[0] : "";
 $rv .= sprintf "<input type=radio name=$_[0]_mode value=2 %s>\n",
 	@v == 2 ? "checked" : "";
-$rv .= sprintf "Soft limit <input name=$_[0]_soft2 size=5 value=\"%s\">\n",
+$rv .= sprintf "$text{'core_25'}<input name=$_[0]_soft2 size=5 value=\"%s\">\n",
 	@v == 2 ? $v[0] : "";
-$rv .= sprintf "Hard limit <input name=$_[0]_hard2 size=5 value=\"%s\"><br>\n",
+$rv .= sprintf "$text{'core_26'}<input name=$_[0]_hard2 size=5 value=\"%s\"><br>\n",
 	@v == 2 ? $v[1] : "";
 return (1, $_[1], $rv);
 }
@@ -216,14 +216,14 @@ sub parse_rlimit
 if ($in{"$_[0]_mode"} == 0) { return ( [ ] ); }
 elsif ($in{"$_[0]_mode"} == 1) {
 	$in{"$_[0]_soft1"} =~ /^(\d+|max)$/ ||
-		&error($in{"$_[0]_soft1"}." is not a valid soft $_[1]");
+		&error($in{"$_[0]_soft1"}.&text('core_27', $_[1]));
 	return ( [ $in{"$_[0]_soft1"} ] );
 	}
 elsif ($in{"$_[0]_mode"} == 2) {
 	$in{"$_[0]_soft2"} =~ /^(\d+|max)$/ ||
-		&error($in{"$_[0]_soft2"}." is not a valid soft $_[1]");
+		&error($in{"$_[0]_soft2"}.&text('core_28', $_[1]));
 	$in{"$_[0]_hard2"} =~ /^(\d+|max)$/ ||
-		&error($in{"$_[0]_hard2"}." is not a valid hard $_[1]");
+		&error($in{"$_[0]_hard2"}.&text('core_29', $_[1]));
 	return ( [ $in{"$_[0]_soft2"}." ".$in{"$_[0]_hard2"} ] );
 	}
 }
@@ -256,9 +256,9 @@ else {
 	push(@plist, undef);
 	}
 $port = @$pref ? $pref->[@$pref-1]->{'value'} : 80;
-$inp = "<b>Default port:</b> <input name=Port size=6 value=\"$port\"><br>\n";
+$inp = "<b>$text{'core_30'}</b> <input name=Port size=6 value=\"$port\"><br>\n";
 $inp .=	"<table border>\n".
-	"<tr $tb> <td><b>Address</b></td> <td><b>Port</b></td> </tr>\n";
+	"<tr $tb> <td><b>$text{'core_31'}</b></td> <td><b>$text{'core_32'}</b></td> </tr>\n";
 for($i=0; $i<@blist+1; $i++) {
 	$inp .= sprintf
 		"<tr><td><input type=radio name=BindAddress_def_$i value=2 %s>".
@@ -269,10 +269,10 @@ for($i=0; $i<@blist+1; $i++) {
 		$blist[$i] eq "*" ? "checked" : "",
 		$blist[$i] && $blist[$i] ne "*" ? "checked" : "",
 		$blist[$i] eq "*" ? "" : $blist[$i];
-	$inp .= "<td>".&opt_input($plist[$i], "Port_$i", "Default", 5)."</td>";
+	$inp .= "<td>".&opt_input($plist[$i], "port_$i", "$text{'core_34'}", 5)."</td>";
 	}
 $inp .= "</table>\n";
-return (2, "Listen on addresses and ports", $inp);
+return (2, $text{'core_35'}, $inp);
 }
 sub save_BindAddress_Listen_Port
 {
@@ -286,16 +286,16 @@ for($i=0; defined($in{"Port_$i"}); $i++) {
 
 	if ($bdef) { push(@blist, "*"); }
 	elsif ($b =~ /^\S+$/ && gethostbyname($b)) { push(@blist, $b); }
-	else { &error("'$b' is not a valid address"); }
+	else { &error(&text('core_36', $b)); }
 
 	if ($pdef) { push(@plist, undef); }
 	elsif ($p =~ /^\d+$/) { push(@plist, $p); }
-	else { &error("'$p' is not a valid port"); }
+	else { &error(&text('core_37', $p)); }
 	}
-if (!@blist) { &error("You must specify at least one address to listen on"); }
+if (!@blist) { &error($text{'core_38'}); }
 
 # Return directives
-$in{'Port'} =~ /^\d+$/ || &error("Invalid default port");
+$in{'Port'} =~ /^\d+$/ || &error($text{'core_39'});
 if (@blist == 1 && !$plist[0]) {
 	# Only one address, and the default port
 	return ( $blist[0] eq "*" ? [ ] : [ $blist[0] ], [ ], [ $in{'Port'} ] );
@@ -341,7 +341,7 @@ else {
 		$kref->{'value'} ? "checked" : "",
 		$kref->{'value'} ? $kref->{'value'} : "";
 	}
-return (1, "Multiple requests per connection", $inp);
+return (1, $text{'core_40'}, $inp);
 }
 sub save_KeepAlive_MaxKeepAliveRequests
 {
@@ -350,7 +350,7 @@ if ($_[0]->{'version'} >= 1.2) {
 	if ($in{'KeepAlive_def'} == 0) { return ( [ "off" ], [ ] ); }
 	elsif ($in{'KeepAlive_def'} == 1) { return ( [ "on" ], [ ] ); }
 	elsif ($in{'KeepAlive'} !~ /^\d+$/) {
-		&error("'$in{'KeepAlive'}' is not a valid number of keepalives");
+		&error(&text('core_41', $in{'KeepAlive'}));
 		}
 	else { return ( [ "on" ], [ $in{'KeepAlive'} ] ); }
 	}
@@ -359,7 +359,7 @@ else {
 	if ($in{'KeepAlive_def'} == 0) { return ( [ 0 ], [ ] ); }
 	elsif ($in{'KeepAlive_def'} == 1) { return ( [ ], [ ] ); }
 	elsif ($in{'KeepAlive'} !~ /^\d+$/) {
-		&error("'$in{'KeepAlive'}' is not a valid number of keepalives");
+		&error(&text('core_78', $in{'KeepAlive'}));
 		}
 	else { return ( [ $in{'KeepAlive'} ], [ ] ); }
 	}
@@ -368,43 +368,43 @@ else {
 sub edit_KeepAliveTimeout
 {
 return (1,
-	"Keep-alive timeout",
-	&opt_input($_[0]->{'value'}, "KeepAliveTimeout", "Default", 5));
+	$text{'core_55'},
+	&opt_input($_[0]->{'value'}, "KeepAliveTimeout", $text{'core_72'}, 5));
 }
 sub save_KeepAliveTimeout
 {
 return &parse_opt("KeepAliveTimeout", '^\d+$',
-		  "Keep-alive timeout must be an integer");
+		  $text{'core_67'});
 }
 
 sub edit_ListenBacklog
 {
 return (1,
-	"Listen queue length",
-	&opt_input($_[0]->{'value'}, "ListenBacklog", "Default", 4));
+	$text{'core_56'},
+	&opt_input($_[0]->{'value'}, "ListenBacklog", $text{'core_73'}, 4));
 }
 sub save_ListenBacklog
 {
 return &parse_opt("ListenBacklog", '^\d+$',
-		  "Listen queue length must be an integer");
+		  $text{'core_68'});
 }
 
 sub edit_SendBufferSize
 {
 return (1,
-	"TCP send buffer size",
-	&opt_input($_[0]->{'value'}, "SendBufferSize", "OS Default", 4));
+	$text{'core_57'},
+	&opt_input($_[0]->{'value'}, "SendBufferSize", $text{'core_74'}, 4));
 }
 sub save_SendBufferSize
 {
 return &parse_opt("SendBufferSize", '^\d+$',
-		  "TCP send buffer size must be an integer");
+		  $text{'core_69'});
 }
 
 sub edit_ServerAdmin
 {
-return (1, "Server admin email address",
-        &opt_input($_[0]->{'value'}, "ServerAdmin", "None", 25));
+return (1, $text{'core_58'},
+        &opt_input($_[0]->{'value'}, "ServerAdmin", $text{'core_75'}, 25));
 }
 sub save_ServerAdmin
 {
@@ -414,20 +414,20 @@ return &parse_opt("ServerAdmin");
 sub edit_TimeOut
 {
 return (1,
-	"Request timeout",
-	&opt_input($_[0]->{'value'}, "TimeOut", "Default", 4));
+	$text{'core_59'},
+	&opt_input($_[0]->{'value'}, "TimeOut", $text{'core_76'}, 4));
 }
 sub save_TimeOut
 {
 return &parse_opt("TimeOut", '^\d+$',
-		  "Request timeout must be an integer");
+		  $text{'core_70'});
 }
 
 sub edit_UseCanonicalName
 {
-return (1, "Use hostname supplied by browser",
+return (1, $text{'core_60'},
         &choice_input($_[0]->{'value'}, "UseCanonicalName",
-	               "", "Yes,off", "No,on", "Default,"));
+	               "", "$text{'core_42'},off", "$text{'core_43'},on", "$text{'core_44'},"));
 }
 sub save_UseCanonicalName
 {
@@ -437,14 +437,14 @@ return &parse_choice("UseCanonicalName", "");
 sub edit_HostNameLookups
 {
 if ($_[1]->{'version'} >= 1.3) {
-	return (1, "Lookup hostnames",
+	return (1, $text{'core_61'},
 		&choice_input($_[0]->{'value'}, "HostNameLookups", "",
-		       "No,off", "Yes,on", "Lookup twice,double", "Default,"));
+		       "$text{'core_45'},off", "$text{'core_46'},on", "$text{'core_47'},double", "$text{'core_48'},"));
 	}
 else {
-	return (1, "Lookup hostnames",
+	return (1, $text{'core_62'},
 		&choice_input($_[0]->{'value'}, "HostNameLookups", "",
-			      "Yes,on", "No,off", "Default,"));
+			      "$text{'core_49'},on", "$text{'core_50'},off", "$text{'core_51'},"));
 	}
 }
 sub save_HostNameLookups
@@ -454,9 +454,9 @@ return &parse_choice("HostNameLookups", "");
 
 sub edit_IdentityCheck
 {
-return (1, "Do RFC1413 user lookups",
+return (1, $text{'core_63'},
 	&choice_input($_[0]->{'value'}, "IdentityCheck", "",
-		      "Yes,on", "No,off", "Default,"));
+		      "$text{'core_52'},on", "$text{'core_53'},off", "$text{'core_54'},"));
 }
 sub save_IdentityCheck
 {
@@ -467,7 +467,7 @@ sub edit_ServerAlias
 {
 local($a, @al);
 foreach $a (@{$_[0]}) { push(@al, split(/\s+/, $a->{'value'})); }
-return (1, "Alternate virtual server names",
+return (1, $text{'core_64'},
 	sprintf "<textarea name=ServerAlias rows=3 cols=25>%s</textarea>\n",
 		join("\n", @al) );
 }
@@ -481,19 +481,19 @@ else { return ( [ ] ); }
 
 sub edit_ServerName
 {
-return (1, "Server hostname",
-	&opt_input($_[0]->{'value'}, "ServerName", "Automatic", 25));
+return (1, $text{'core_65'},
+	&opt_input($_[0]->{'value'}, "ServerName", $text{'core_77'}, 25));
 }
 sub save_ServerName
 {
-return &parse_opt("ServerName", '^\S+$', "Invalid server hostname");
+return &parse_opt("ServerName", '^\S+$', $text{'core_71'});
 }
 
 sub edit_NameVirtualHost
 {
 local(@nv, $nv);
 foreach $nv (@{$_[0]}) { push(@nv, $nv->{'value'}); }
-return (1, "Addresses for name virtual servers",
+return (1, $text{'core_66'},
 	"<textarea name=NameVirtualHost rows=3 cols=30>".
 	join("\n", @nv)."</textarea>");
 }
@@ -505,8 +505,7 @@ foreach $nv (@nv) {
 	if ($nv =~ /^(\S+):(\d+)$/) { $addr = $1; }
 	else { $addr = $nv; }
 	if (!gethostbyname($addr)) {
-		&error("'$addr' is not a valid address for name ".
-		       "virtual servers");
+		&error(&text('core_79', $addr));
 		}
 	}
 if (@nv) { return ( \@nv ); }
@@ -518,30 +517,30 @@ else { return ( [ ] ); }
 sub edit_AccessFileName
 {
 return (1,
-        "Per-directory options file",
-        &opt_input($_[0]->{'value'}, "AccessFileName", "Default", 20));
+        $text{'core_103'},
+        &opt_input($_[0]->{'value'}, "AccessFileName", $text{'core_110'}, 20));
 }
 sub save_AccessFileName
 {
 if ($_[0]->{'version'} < 1.3) {
 	return &parse_opt("AccessFileName", '^(\S+)$',
-	                  "Only one options file is allowed");
+	                  $text{'core_108'});
 	}
 else {
 	return &parse_opt("AccessFileName", '\S',
-			     "No options file entered");
+			     $text{'core_109'});
 	}
 }
 
 @AllowOverride_v = ("AuthConfig", "FileInfo", "Indexes", "Limit", "Options");
-@AllowOverride_d = ("Authentication options", "MIME types and encodings",
-                    "Indexing and index files", "Hostname access control",
-                    "Directory options");
+@AllowOverride_d = ("$text{'core_80'}", "$text{'core_81'}",
+                    "$text{'core_82'}", "$text{'core_83'}",
+                    "$text{'core_84'}");
 sub edit_AllowOverride
 {
 local($rv, @ov, %over, $rv);
 $rv = &choice_input($_[0] ? 0 : 1, "AllowOverride_def", 1,
-		 "Default,1", "Selected below...,0");
+		 "$text{'core_85'},1", "$text{'core_86'},0");
 $rv .= "<table border><tr><td>\n";
 if ($_[0]) { @ov = split(/\s+/, $_[0]->{'value'}); }
 else { @ov = ("All"); }
@@ -556,7 +555,7 @@ for($i=0; $i<@AllowOverride_v; $i++) {
 	        $AllowOverride_d[$i];
 	}
 $rv .= "</td></tr></table>\n";
-return (1, "Options file can override..", $rv);
+return (1, $text{'core_104'}, $rv);
 }
 sub save_AllowOverride
 {
@@ -573,9 +572,9 @@ else { return ( [ join(' ', @ov) ] ); }
 sub edit_ContentDigest
 {
 return (1,
-	"Generate MD5 digests",
+	$text{'core_105'},
 	&choice_input($_[0]->{'value'}, "ContentDigest", "",
-		      "Yes,on", "No,off", "Default,"));
+		      "$text{'core_87'},on", "$text{'core_88'},off", "$text{'core_89'},"));
 }
 sub save_ContentDigest
 {
@@ -584,14 +583,14 @@ return &parse_choice("ContentDigest", "");
 
 sub edit_DocumentRoot
 {
-return (2, "Document root directory",
-	&opt_input($_[0]->{'words'}->[0], "DocumentRoot", "Default", 40).
+return (2, $text{'core_106'},
+	&opt_input($_[0]->{'words'}->[0], "DocumentRoot", $text{'core_111'}, 40).
 	&file_chooser_button("DocumentRoot", 1));
 }
 sub save_DocumentRoot
 {
 $in{'DocumentRoot_def'} || -d $in{'DocumentRoot'} ||
-	&error("document root '$in{'DocumentRoot'}' does not exist");
+	&error(&text('core_112', $in{'DocumentRoot'}));
 return &parse_opt("DocumentRoot");
 }
 
@@ -600,12 +599,12 @@ sub edit_Options
 local(@po, @o, $o, %opts, $opts, $po, @pon, $i);
 @po = ("ExecCGI", "FollowSymLinks", "Includes", "IncludesNOEXEC",
        "Indexes", "MultiViews", "SymLinksIfOwnerMatch");
-@pon = ("Execute CGI programs", "Follow symbolic links",
-	"Server-side includes and execs", "Server-side includes",
-	"Generate directory indexes", "Generate Multiviews",
-	"Follow symbolic links if owners match");
-$opts = &choice_input($_[0] ? 0 : 1, "Options_def", 1, "Default,1",
-		      "Selected below..,0")."<br>\n";
+@pon = ("$text{'core_90'}", "$text{'core_91'}",
+	"$text{'core_92'}", "$text{'core_93'}",
+	"$text{'core_94'}", "$text{'core_95'}",
+	"$text{'core_96'}");
+$opts = &choice_input($_[0] ? 0 : 1, "Options_def", 1, "$text{'core_97'},1",
+		      "$text{'core_98'},0")."<br>\n";
 @o = split(/\s+/, $_[0]->{'value'});
 foreach $o (split(/\s+/, $_[0]->{'value'})) {
 	if ($o =~ /^\+(.*)$/) { $opts{$1} = 2; }
@@ -620,24 +619,24 @@ if ($opts{'All'}) {
 		}
 	}
 $opts .= "<table border>\n";
-$opts .= "<tr $tb> <td><b>Option</b></td> <td><b>Set for directory</b></td>\n";
-$opts .= "<td><b>Merge with parent</b></td> </tr>\n";
+$opts .= "<tr $tb> <td><b>$text{'core_195'}</b></td> <td><b>$text{'core_196'}</b></td>\n";
+$opts .= "<td><b>$text{'core_197'}</b></td> </tr>\n";
 for($i=0; $i<@po; $i++) {
 	$po = $po[$i];
 	$opts .= "<tr $cb> <td><b>$pon[$i]</b></td> <td>\n";
-	$opts .= sprintf "<input type=radio name=$po value=1 %s> Yes\n",
+	$opts .= sprintf "<input type=radio name=$po value=1 %s> $text{'core_99'}\n",
 			$opts{$po}==1 ? "checked" : "";
-	$opts .= sprintf "<input type=radio name=$po value=0 %s> No\n",
+	$opts .= sprintf "<input type=radio name=$po value=0 %s> $text{'core_100'}\n",
 			$opts{$po}==0 ? "checked" : "";
 	$opts .= "</td> <td>\n";
-	$opts .= sprintf "<input type=radio name=$po value=2 %s> Enable\n",
+	$opts .= sprintf "<input type=radio name=$po value=2 %s> $text{'core_101'}\n",
 			$opts{$po}==2 ? "checked" : "";
-	$opts .= sprintf "<input type=radio name=$po value=3 %s> Disable\n",
+	$opts .= sprintf "<input type=radio name=$po value=3 %s> $text{'core_102'}\n",
 			$opts{$po}==3 ? "checked" : "";
 	$opts .= "</td> </tr>\n";
 	}
 $opts .= "</table>\n";
-return (2, "Directory options", $opts);
+return (2, $text{'core_107'}, $opts);
 }
 sub save_Options
 {
@@ -656,22 +655,22 @@ return @rv ? ( [ join(' ', @rv) ] ) : ( [ "None" ] );
 sub edit_ServerPath
 {
 return (2,
-	"Virtual server path",
-	&opt_input($_[0]->{'value'}, "ServerPath", "Default", 40).
+	$text{'core_117'},
+	&opt_input($_[0]->{'value'}, "ServerPath", $text{'core_120'}, 40).
 	&file_chooser_button("ServerPath", 1));
 }
 sub save_ServerPath
 {
 return &parse_opt("ServerPath", '^\/\S*$',
-		  "Virtual server path must start with a /");
+		  $text{'core_119'});
 }
 
 sub edit_ServerSignature
 {
-return (1, "Error message footer",
+return (1, $text{'core_118'},
 	&choice_input($_[0]->{'value'}, "ServerSignature", undef,
-		      "Email address,Email", "Server name,On",
-		      "None,Off", "Default,"));
+		      "$text{'core_113'},Email", "$text{'core_114'},On",
+		      "$text{'core_115'},Off", "$text{'core_116'},"));
 }
 sub save_ServerSignature
 {
@@ -683,13 +682,13 @@ return &parse_choice("ServerSignature", undef);
 sub edit_DefaultType
 {
 return (1,
-	"Default MIME Type",
-	&opt_input($_[0]->{'value'}, "DefaultType", "Default", 20));
+	$text{'core_121'},
+	&opt_input($_[0]->{'value'}, "DefaultType", $text{'core_123'}, 20));
 }
 sub save_DefaultType
 {
 return &parse_opt("DefaultType", '^(\S+)\/(\S+)$',
-		  "Default MIME type must be in the form type/subtype");
+		  $text{'core_122'});
 }
 
 #########################################################################
@@ -698,8 +697,8 @@ sub edit_AuthName
 {
 my $val = $_[1]->{'version'} >= 1.3 ? $_[0]->{'words'}->[0]
 				    : $_[0]->{'value'};
-return (1, "Authentication realm name",
-        &opt_input($val, "AuthName", "Default", 25));
+return (1, $text{'core_124'},
+        &opt_input($val, "AuthName", $text{'core_126'}, 25));
 }
 sub save_AuthName
 {
@@ -717,7 +716,7 @@ foreach $a ("", "Basic", "Digest") {
 	        lc($_[0]->{'value'}) eq lc($a) ? "selected" : "";
 	}
 $rv .= "</select>";
-return (1, "Authentication type", $rv);
+return (1, $text{'core_125'}, $rv);
 }
 sub save_AuthType
 {
@@ -747,7 +746,7 @@ $rv .= sprintf
 $rv .= sprintf
       "<input type=radio name=require_mode value=3 %s> All valid users<br>\n",
       $mode eq "valid-user" ? "checked" : "";
-return (1, "Restrict access by login", $rv);
+return (1, $text{'core_130'}, $rv);
 }
 sub save_require
 {
@@ -759,9 +758,9 @@ else { return ( [ "valid-user" ] ); }
 
 sub edit_Satisfy
 {
-return (1, "Clients must satisfy",
-	&choice_input_vert($_[0]->{'value'}, "Satisfy", "", "Default,",
-			   "All access controls,all","Any access control,any"));
+return (1, $text{'core_131'},
+	&choice_input_vert($_[0]->{'value'}, "Satisfy", "", "$text{'core_127'},",
+			   "$text{'core_128'},all","$text{'core_129'},any"));
 }
 sub save_Satisfy
 {
@@ -772,93 +771,93 @@ return &parse_choice("Satisfy", "");
 # Misc. directives
 sub edit_CoreDumpDirectory
 {
-return (1, "Core dump directory",
-	 &opt_input($_[0]->{'value'}, "CoreDumpDirectory", "Server root", 20).
+return (1, $text{'core_137'},
+	 &opt_input($_[0]->{'value'}, "CoreDumpDirectory", $text{'core_155'}, 20).
 	 &file_chooser_button("CoreDumpDirectory", 1));
 }
 sub save_CoreDumpDirectory
 {
-return &parse_opt("CoreDumpDirectory", '^\S+$', "Invalid core dump directory");
+return &parse_opt("CoreDumpDirectory", '^\S+$', $text{'core_147'});
 }
 
 sub edit_LockFile
 {
-return (1, "Server lock file",
-        &opt_input($_[0]->{'value'}, "LockFile", "Default", 20).
+return (1, $text{'core_138'},
+        &opt_input($_[0]->{'value'}, "LockFile", $text{'core_156'}, 20).
         &file_chooser_button("LockFile", 0));
 }
 sub save_LockFile
 {
-return &parse_opt("LockFile", '^\S+', "Invalid lock file");
+return &parse_opt("LockFile", '^\S+', $text{'core_148'});
 }
 
 sub edit_LimitRequestBody
 {
-return (1, "Maximum request body size",
-	&opt_input($_[0]->{'value'}, "LimitRequestBody", "Default", 8)."bytes");
+return (1, $text{'core_139'},
+	&opt_input($_[0]->{'value'}, "LimitRequestBody", $text{'core_157'}, 8)."bytes");
 }
 sub save_LimitRequestBody
 {
-return &parse_opt("LimitRequestBody", '^\d+$', "Invalid request body size");
+return &parse_opt("LimitRequestBody", '^\d+$', $text{'core_149'});
 }
 
 sub edit_LimitRequestFields
 {
-return (1, "Maximum headers in request",
-	&opt_input($_[0]->{'value'}, "LimitRequestFields", "Default", 6));
+return (1, $text{'core_140'},
+	&opt_input($_[0]->{'value'}, "LimitRequestFields", $text{'core_158'}, 6));
 }
 sub save_LimitRequestFields
 {
-return &parse_opt("LimitRequestFields", '^\d+$', "Invalid number of headers");
+return &parse_opt("LimitRequestFields", '^\d+$', $text{'core_150'});
 }
 
 sub edit_LimitRequestFieldsize
 {
-return (1, "Maximum request header size",
-	&opt_input($_[0]->{'value'}, "LimitRequestFieldsize", "Default", 6));
+return (1, $text{'core_141'},
+	&opt_input($_[0]->{'value'}, "LimitRequestFieldsize", $text{'core_159'}, 6));
 }
 sub save_LimitRequestFieldsize
 {
-return &parse_opt("LimitRequestFieldsize", '^\d+$', "Invalid header size");
+return &parse_opt("LimitRequestFieldsize", '^\d+$', $text{'core_151'});
 }
 
 sub edit_LimitRequestLine
 {
-return (1, "Maximum request line size",
-	&opt_input($_[0]->{'value'}, "LimitRequestLine", "Default", 6));
+return (1, $text{'core_142'},
+	&opt_input($_[0]->{'value'}, "LimitRequestLine", $text{'core_160'}, 6));
 }
 sub save_LimitRequestLine
 {
-return &parse_opt("LimitRequestLine", '^\d+$', "Invalid request line size");
+return &parse_opt("LimitRequestLine", '^\d+$', $text{'core_152'});
 }
 
 sub edit_PidFile
 {
-return (1, "Server PID file",
-        &opt_input($_[0]->{'value'}, "PidFile", "Default", 20).
+return (1, $text{'core_143'},
+        &opt_input($_[0]->{'value'}, "PidFile", $text{'core_161'}, 20).
         &file_chooser_button("PidFile", 0));
 }
 sub save_PidFile
 {
-return &parse_opt("PidFile", '^\S+$', "Invalid PID file");
+return &parse_opt("PidFile", '^\S+$', $text{'core_153'});
 }
 
 sub edit_ScoreBoardFile
 {
-return (1, "Shared memory scoreboard file",
-        &opt_input($_[0]->{'value'}, "ScoreBoardFile", "Default", 20).
+return (1, $text{'core_144'},
+        &opt_input($_[0]->{'value'}, "ScoreBoardFile", $text{'core_162'}, 20).
         &file_chooser_button("ScoreBoardFile", 0));
 }
 sub save_ScoreBoardFile
 {
-return &parse_opt("ScoreBoardFile", '^\S+$', "Invalid scoreboard file");
+return &parse_opt("ScoreBoardFile", '^\S+$', $text{'core_154'});
 }
 
 sub edit_ServerType
 {
-return (1, "Server execution",
+return (1, $text{'core_145'},
         &choice_input($_[0]->{'value'}, "ServerType", "standalone",
-                      "Standalone,standalone", "Run from inetd,inetd"));
+                      "$text{'core_132'},standalone", "$text{'core_133'},inetd"));
 }
 sub save_ServerType
 {
@@ -867,10 +866,10 @@ return &parse_choice("ServerType", "standalone");
 
 sub edit_ServerTokens
 {
-return (1, "Server HTTP header",
+return (1, $text{'core_146'},
 	&select_input($_[0]->{'value'}, "ServerTokens", "Full",
-		      "Version and OS and modules,Full",
-		      "Version and OS,OS", "Version only,Min"));
+		      "$text{'core_134'},Full",
+		      "$text{'core_135'},OS", "$text{'core_136'},Min"));
 }
 sub save_ServerTokens
 {
@@ -884,23 +883,23 @@ sub edit_Group
 local($rv, @ginfo);
 $rv = sprintf "<input type=radio name=Group value=0 %s> Default&nbsp;\n",
        $_[0] ? "" : "checked";
-$rv .= sprintf "<input type=radio name=Group value=1 %s> Group name\n",
+$rv .= sprintf "<input type=radio name=Group value=1 %s>$text{'core_163'}\n",
         $_[0] && $_[0]->{'value'} !~ /^#/ ? "checked" : "";
 $rv .= sprintf "<input name=Group_name size=8 value=\"%s\"> %s&nbsp;\n",
 	$_[0]->{'value'} !~ /^#/ ? $_[0]->{'value'} : "",
 	&group_chooser_button("Group_name", 0);
-$rv .= sprintf "<input type=radio name=Group value=2 %s> Group ID\n",
+$rv .= sprintf "<input type=radio name=Group value=2 %s>$text{'core_164'}\n",
         $_[0]->{'value'} =~ /^#/ ? "checked" : "";
 $rv .= sprintf "<input name=Group_id size=6 value=\"%s\">\n",
 	 $_[0]->{'value'} =~ /^#(.*)$/ ? $1 : "";
-return (2, "Run as Unix group", $rv);
+return (2, $text{'core_167'}, $rv);
 }
 sub save_Group
 {
 if ($in{'Group'} == 0) { return ( [ ] ); }
 elsif ($in{'Group'} == 1) { return ( [ $in{'Group_name'} ] ); }
 elsif ($in{'Group_id'} !~ /^\-?\d+$/) {
-	&error("'$in{'Group_id'}' is not a valid group ID");
+	&error(&text('core_169', $in{'Group_id'}));
 	}
 else { return ( [ "#$in{'Group_id'}" ] ); }
 }
@@ -910,23 +909,23 @@ sub edit_User
 local($rv, @uinfo);
 $rv = sprintf "<input type=radio name=User value=0 %s> Default&nbsp;\n",
        $_[0] ? "" : "checked";
-$rv .= sprintf "<input type=radio name=User value=1 %s> User name\n",
+$rv .= sprintf "<input type=radio name=User value=1 %s>$text{'core_165'}\n",
         $_[0] && $_[0]->{'value'} !~ /^#/ ? "checked" : "";
 $rv .= sprintf "<input name=User_name size=8 value=\"%s\"> %s&nbsp;\n",
 	$_[0]->{'value'} !~ /^#/ ? $_[0]->{'value'} : "",
 	&user_chooser_button("User_name", 0);
-$rv .= sprintf "<input type=radio name=User value=2 %s> User ID\n",
+$rv .= sprintf "<input type=radio name=User value=2 %s>$text{'core_166'}\n",
         $_[0]->{'value'} =~ /^#/ ? "checked" : "";
 $rv .= sprintf "<input name=User_id size=6 value=\"%s\">\n",
 	 $_[0]->{'value'} =~ /^#(.*)$/ ? $1 : "";
-return (2, "Run as Unix user", $rv);
+return (2, $text{'core_168'}, $rv);
 }
 sub save_User
 {
 if ($in{'User'} == 0) { return ( [ ] ); }
 elsif ($in{'User'} == 1) { return ( [ $in{'User_name'} ] ); }
 elsif ($in{'User_id'} !~ /^\-?\d+$/) {
-	&error("'$in{'User_id'}' is not a valid user ID");
+	&error(&text('core_170', $in{'User_id'}));
 	}
 else { return ( [ "#$in{'User_id'}" ] ); }
 }
@@ -937,8 +936,8 @@ sub edit_ErrorDocument
 {
 local($rv, $len, $i);
 $rv = "<table border width=100%>\n";
-$rv .= "<tr $tb> <td><b>Error code</b></td> <td><b>Response</b></td> ".
-       "<td><b>URL or message</b></td> </tr>\n";
+$rv .= "<tr $tb> <td><b>$text{'core_173'}</b></td> <td><b>$text{'core_174'}</b></td> ".
+       "<td><b>$text{'core_175'}</b></td> </tr>\n";
 $len = @{$_[0]} + 1;
 for($i=0; $i<$len; $i++) {
 	$v = $_[0]->[$i]->{'value'};
@@ -949,14 +948,14 @@ for($i=0; $i<$len; $i++) {
 	$rv .= "<tr $cb>\n";
 	$rv .= "<td><input name=ErrorDocument_code_$i size=3 value=$code></td>\n";
 	$rv .= "<td><input type=radio name=ErrorDocument_type_$i value=0 ".
-	       ($type==0 ? "checked" : "")."> Goto URL..\n";
+	       ($type==0 ? "checked" : "").">$text{'core_171'}\n";
 	$rv .= "<input type=radio name=ErrorDocument_type_$i value=1 ".
-	       ($type==1 ? "checked" : "")."> Show message..</td>\n";
+	       ($type==1 ? "checked" : "").">$text{'core_172'}</td>\n";
 	$rv .= "<td><input name=ErrorDocument_url_$i size=40 value=\"$url\"></td>\n";
 	$rv .= "</tr>\n";
 	}
 $rv .= "</table>\n";
-return (2, "Custom error responses", $rv);
+return (2, $text{'core_176'}, $rv);
 }
 sub save_ErrorDocument
 {
@@ -964,9 +963,9 @@ local($i, $code, $url, @rv);
 for($i=0; defined($in{"ErrorDocument_code_$i"}); $i++) {
 	$code = $in{"ErrorDocument_code_$i"}; $url = $in{"ErrorDocument_url_$i"};
 	if ($code !~ /\S/ && $url !~ /\S/) { next; }
-	$code =~ /^\d\d\d$/ || &error("'$code' is not a valid error code");
+	$code =~ /^\d\d\d$/ || &error(&text('core_177', $code));
 	if ($in{"ErrorDocument_type_$i"} == 0) {
-		$url =~ /^\S+$/ || &error("'$url' is not a valid URL");
+		$url =~ /^\S+$/ || &error(&text('core_178', $url));
 		push(@rv, "$code $url");
 		}
 	elsif ($_[0]->{'version'} >= 1.2) { push(@rv, "$code \"$url"); }
@@ -980,8 +979,8 @@ return ( \@rv );
 sub edit_ErrorLog
 {
 if ($_[1]->{'version'} < 1.3) {
-	return (1, "Error log file",
-		&opt_input($_[0]->{'value'}, "ErrorLog", "Default", 20).
+	return (1, $text{'core_183'},
+		&opt_input($_[0]->{'value'}, "ErrorLog", $text{'core_186'}, 20).
 		&file_chooser_button("ErrorLog", 0));
 	}
 else {
@@ -991,27 +990,27 @@ else {
 		   $v =~ /^\|/ ? 1 : 0;
 	$rv = sprintf "<input type=radio name=ErrorLog_type value=3 %s>\n",
 		$t == 3 ? "checked" : "";
-	$rv .= "Default\n";
+	$rv .= "$text{'core_179'}";
 	$rv .= sprintf "<input type=radio name=ErrorLog_type value=2 %s>\n",
 		$t == 2 ? "checked" : "";
-	$rv .= "System Log<br>\n";
+	$rv .= "$text{'core_180'}<br>\n";
 	$rv .= sprintf "<input type=radio name=ErrorLog_type value=0 %s>\n",
 		$t == 0 ? "checked" : "";
-	$rv .= sprintf "File <input name=ErrorLog_file size=25 value='%s'>\n",
+	$rv .= sprintf "$text{'core_181'}<input name=ErrorLog_file size=25 value='%s'>\n",
 		$t == 0 ? $v : "";
 	$rv .= sprintf "<input type=radio name=ErrorLog_type value=1 %s>\n",
 		$t == 1 ? "checked" : "";
-	$rv .= sprintf "Program <input name=ErrorLog_prog size=25 value='%s'><br>\n",
+	$rv .= sprintf "$text{'core_182'}<input name=ErrorLog_prog size=25 value='%s'><br>\n",
 		$t == 1 ? substr($v, 1) : "";
-	return (2, "Error log to", $rv);
+	return (2, $text{'core_184'}, $rv);
 	}
 }
 sub save_ErrorLog
 {
 if ($_[0]->{'version'} < 1.3) {
 	$in{'ErrorLog_def'} || &allowed_auth_file($in{'ErrorLog'}) ||
-		&error("Error log file is not under the allowed directory");
-	return &parse_opt("ErrorLog", '^\S+$', "Invalid error log file");
+		&error($text{'core_187'});
+	return &parse_opt("ErrorLog", '^\S+$', $text{'core_185'});
 	}
 else {
 	if ($in{'ErrorLog_type'} == 3) {
@@ -1019,16 +1018,16 @@ else {
 		}
 	elsif ($in{'ErrorLog_type'} == 0) {
 		$in{'ErrorLog_file'} =~ /\S/ ||
-		    &error("Missing error log file");
+		    &error($text{'core_188'});
 		&allowed_auth_file($in{'ErrorLog_file'}) ||
-		    &error("Error log file is not under the allowed directory");
+		    &error($text{'core_189'});
 		return ( [ $in{'ErrorLog_file'} ] );
 		}
 	elsif ($in{'ErrorLog_type'} == 1) {
 		$in{'ErrorLog_prog'} =~ /\S/ ||
-		    &error("Missing error log program");
+		    &error($text{'core_190'});
 		$access{'pipe'} ||
-		    &error("You are not allowed to pipe logs to programs");
+		    &error($text{'core_191'});
 		return ( [ "\"|$in{'ErrorLog_prog'}\"" ] );
 		}
 	else {
@@ -1064,16 +1063,15 @@ if (@{$_[0]}) {
 	}
 else { foreach $m (@allmods) { $mods{$m} = "checked"; } }
 $rv = &choice_input(@{$_[0]} ? 1 : 0, "ClearModuleList", 1,
-		    "All modules,0", "Selected modules..,1")."<br>\n";
+		    "$text{'core_192'},0", "$text{'core_193'},1")."<br>\n";
 $rv .= "<table>\n";
 foreach $m (@allmods) {
 	if ($i%4 == 0) { $rv .= "<tr>\n"; }
-	$rv .= "<td><input name=AddModule type=checkbox value=$m ".
-	       "$mods{$m}> $m</td>\n";
+	$rv .= "<td><input name=AddModule type=checkbox value=$m $mods{$m}> $m</td>\n";
 	if ($i++%4 == 3) { $rv .= "</tr>\n"; }
 	}
 $rv .= "</table>\n";
-return (2, "Active modules", $rv);
+return (2, $text{'core_194'}, $rv);
 }
 sub save_ClearModuleList_AddModule
 {
