@@ -17,35 +17,35 @@ return ("cgi-script");
 
 sub edit_ScriptLog
 {
-return (1, "CGI Script log",
-        &opt_input($_[0]->{'value'}, "ScriptLog", "None", 20).
+return (1, "$text{'mod_cgi_0'}",
+        &opt_input($_[0]->{'value'}, "ScriptLog", "$text{'mod_cgi_1'}", 20).
         &file_chooser_button("ScriptLog", 0));
 }
 sub save_ScriptLog
 {
 $in{'ScriptLog_def'} || &allowed_auth_file($in{'ScriptLog'}) ||
-	&error("CGI script log is not under the allowed directory");
-return &parse_opt("ScriptLog", '^\S+$', "Invalid CGI script log file");
+	&error($text{'mod_cgi_9'});
+return &parse_opt("ScriptLog", '^\S+$', "$text{'mod_cgi_2'}");
 }
 
 sub edit_ScriptLogLength
 {
-return (1, "Maximum CGI log size",
-        &opt_input($_[0]->{'value'}, "ScriptLogLength", "Default", 8)."bytes");
+return (1, "$text{'mod_cgi_3'}",
+        &opt_input($_[0]->{'value'}, "ScriptLogLength", "$text{'mod_cgi_4'}", 8)."bytes");
 }
 sub save_ScriptLogLength
 {
-return &parse_opt("ScriptLogLength", '^\d+$', "CGI log size must be an integer");
+return &parse_opt("ScriptLogLength", '^\d+$', "$text{'mod_cgi_5'}");
 }
 
 sub edit_ScriptLogBuffer
 {
-return (1, "Maximum logged post data size",
-        &opt_input($_[0]->{'value'}, "ScriptLogBuffer", "Default", 6)."bytes");
+return (1, "$text{'mod_cgi_6'}",
+        &opt_input($_[0]->{'value'}, "ScriptLogBuffer", "$text{'mod_cgi_7'}", 6)."bytes");
 }
 sub save_ScriptLogBuffer
 {
-return &parse_opt("ScriptLogBuffer", '^\d+$', "Post data size must be an integer");
+return &parse_opt("ScriptLogBuffer", '^\d+$', "$text{'mod_cgi_8'}");
 }
 
 1;
