@@ -21,7 +21,7 @@ sub edit_DirectoryIndex
 local($rv);
 $rv = sprintf "<textarea name=DirectoryIndex rows=5 cols=20>%s</textarea>\n",
         join("\n", split(/\s+/, $_[0]->{'value'}));
-return (1, "Directory index files", $rv);
+return (1, "$text{'mod_dir_0'}", $rv);
 }
 sub save_DirectoryIndex
 {
