@@ -10,21 +10,21 @@ return &make_directives($rv, $_[0], "mod_log_agent");
 sub edit_AgentLog
 {
 local($rv);
-$rv = sprintf "<input type=radio name=AgentLog_mode value=0 %s> Default\n",
+$rv = sprintf "<input type=radio name=AgentLog_mode value=0 %s> $text{'mod_log_agent_0'}\n",
        $_[0] ? "" : "checked";
-$rv .= sprintf "<input type=radio name=AgentLog_mode value=1 %s> File..",
+$rv .= sprintf "<input type=radio name=AgentLog_mode value=1 %s> $text{'mod_log_agent_1'}",
 	 $_[0] && $_[0]->{'value'} !~ /^\|/ ? "checked" : "";
-$rv .= sprintf "<input type=radio name=AgentLog_mode value=2 %s> Program..",
+$rv .= sprintf "<input type=radio name=AgentLog_mode value=2 %s> $text{'mod_log_agent_2'}",
 	 $_[0]->{'value'} =~ /^\|/ ? "checked" : "";
 $rv .= sprintf "<input name=AgentLog size=20 value=\"%s\">\n",
         $_[0]->{'value'} =~ /^\|(.*)$/ ? $1 : $_[0]->{'value'};
-return (1, "Browser log file", $rv); 
+return (1, "$text{'mod_log_agent_3'}", $rv); 
 }
 sub save_AgentLog
 {
 if ($in{'AgentLog_mode'} == 0) { return ( [ ] ); }
 $in{'AgentLog'} =~ /^\S+$/ ||
-	&error("$in{'AgentLog'} is not a valid agent log filename");
+	&error(&text('mod_log_agent_4', $in{'AgentLog'}));
 if ($in{'AgentLog_mode'} == 1) { return ( [ $in{'AgentLog'} ] ); }
 else { return ( [ "|$in{'AgentLog'}" ] ); }
 }
