@@ -9,13 +9,13 @@ return &make_directives($rv, $_[0], "mod_mime_magic");
 
 sub edit_MimeMagicFile
 {
-return (1, "MIME magic numbers file",
-        &opt_input($_[0]->{'value'}, "MimeMagicFile", "None", 20).
+return (1, "$text{'mod_mime_magic_0'}",
+        &opt_input($_[0]->{'value'}, "MimeMagicFile", "$text{'mod_mime_magic_1'}", 20).
         &file_chooser_button("MimeMagicFile", 1));
 }
 sub save_MimeMagicFile
 {
-return &parse_opt("MimeMagicFile", '^\S+$', "Invalid MIME magic numbers filename");
+return &parse_opt("MimeMagicFile", '^\S+$', "$text{'mod_mime_magic_2'}");
 }
 
 1;
