@@ -16,9 +16,9 @@ return ("type-map");
 sub edit_CacheNegotiatedDocs
 {
 local($v); $v = $_[0] ? "1" : "0";
-return (1, "Cache content-negotiated documents?",
+return (1, "$text{'mod_negotiation_0'}",
         &choice_input($v, "CacheNegotiatedDocs", "0",
-        "Yes,1", "No,0"));
+        "$text{'mod_negotiation_1'},1", "$text{'mod_negotiation_2'},0"));
 }
 sub save_CacheNegotiatedDocs
 {
@@ -27,12 +27,12 @@ return $in{'CacheNegotiatedDocs'} ? ( [ "" ] ) : ( [ ] );
 
 sub edit_LanguagePriority
 {
-return (1, "Language priority for multi-views",
-        &opt_input($_[0]->{'value'}, "LanguagePriority", "Default", 15));
+return (1, "$text{'mod_negotiation_3'}",
+        &opt_input($_[0]->{'value'}, "LanguagePriority", "$text{'mod_negotiation_4'}", 15));
 }
 sub save_LanguagePriority
 {
-return &parse_opt("LanguagePriority", '\S', "Missing language priorities");
+return &parse_opt("LanguagePriority", '\S', "$text{'mod_negotiation_5'}");
 }
 
 1;
