@@ -10,9 +10,9 @@ return &make_directives($rv, $_[0], "mod_speling");
 
 sub edit_CheckSpelling
 {
-return (1, "Automatically correct misspelled URLs?",
+return (1, "$text{'mod_speling_0'}",
         &choice_input($_[0]->{'value'}, "CheckSpelling",
-        "", "No,Off", "Yes,On", "Default,"));
+        "", "$text{'mod_speling_1'},Off", "$text{'mod_speling_2'},On", "$text{'mod_speling_3'},"));
 }
 sub save_CheckSpelling
 {
