@@ -14,9 +14,9 @@ return ("server-status");
 
 sub edit_ExtendedStatus
 {
-return (1, "Display extended status information",
+return (1, "$text{'mod_status_0'}",
         &choice_input($_[0]->{'value'}, "ExtendedStatus",
-	               "off", "Yes,on", "No,off"));
+	               "off", "$text{'mod_status_1'},on", "$text{'mod_status_2'},off"));
 }
 sub save_ExtendedStatus
 {
