@@ -23,7 +23,7 @@ sub get_config_parent
 return { 'file' => $config{'named_conf'},
 	 'type' => 1,
 	 'line' => 0,
-	 'eline' => $lines_count{$config{'named_conf'}}-1,
+	 'eline' => $lines_count{$config{'named_conf'}},
 	 'members' => &get_config() };
 }
 
@@ -212,7 +212,7 @@ for($i=0; $i<@oldv || $i<@newv; $i++) {
 		# a new directive is being added.. put it at the end of
 		# the parent
 		if (!$_[4]) {
-			$lref = &read_file_lines($_[0]->{'file'});
+			$lref = &read_file_lines($config{'chroot'}.$_[0]->{'file'});
 			@nl = &directive_lines($newv[$i], $_[3]);
 			splice(@$lref, $_[0]->{'eline'}, 0, @nl);
 			$newv[$i]->{'file'} = $_[0]->{'file'};
@@ -227,7 +227,7 @@ for($i=0; $i<@oldv || $i<@newv; $i++) {
 	elsif ($i >= @newv) {
 		# a directive was deleted
 		if (!$_[4]) {
-			$lref = &read_file_lines($oldv[$i]->{'file'});
+			$lref = &read_file_lines($config{'chroot'}.$oldv[$i]->{'file'});
 			$ol = $oldv[$i]->{'eline'} - $oldv[$i]->{'line'} + 1;
 			splice(@$lref, $oldv[$i]->{'line'}, $ol);
 			&renumber(&get_config(), $oldv[$i]->{'eline'},
@@ -238,7 +238,7 @@ for($i=0; $i<@oldv || $i<@newv; $i++) {
 	else {
 		# updating some directive
 		if (!$_[4]) {
-			$lref = &read_file_lines($oldv[$i]->{'file'});
+			$lref = &read_file_lines($config{'chroot'}.$oldv[$i]->{'file'});
 			@nl = &directive_lines($newv[$i], $_[3]);
 			$ol = $oldv[$i]->{'eline'} - $oldv[$i]->{'line'} + 1;
 			splice(@$lref, $oldv[$i]->{'line'}, $ol, @nl);
@@ -425,7 +425,7 @@ local($conf, @zl, $rev, $z, $revconf, $revfile, $revrec, @revrecs, $addr, $rr);
 $conf = &get_config();
 @zl = &find("zone", $conf);
 @octs = split(/\./, $_[0]);
-for($i=2; $i>=0; $i--) {
+DOMAIN: for($i=2; $i>=0; $i--) {
 	$rev = &ip_to_arpa(join('.', @octs[0..$i]));
 	$rev =~ s/\.$//g;
 	foreach $z (@zl) {
@@ -434,7 +434,7 @@ for($i=2; $i>=0; $i--) {
 		    $typed->{'value'} eq "master") {
 			# found the reverse master domain
 			$revconf = $z;
-			last;
+			last DOMAIN;
 			}
 		}
 	}
@@ -467,7 +467,7 @@ local $host = $_[0]; $host =~ s/\.$//;
 local $conf = &get_config();
 local @zl = &find("zone", $conf);
 local @parts = split(/\./, $host);
-for($i=@parts-1; $i>0; $i--) {
+DOMAIN: for($i=1; $i<@parts; $i++) {
 	local $fwd = join(".", @parts[$i .. @parts-1]);
 	foreach $z (@zl) {
 		local $typed;
@@ -476,7 +476,7 @@ for($i=@parts-1; $i>0; $i--) {
 		    $typed->{'value'} eq "master") {
 			# Found the forward master!
 			$fwdconf = $z;
-			last;
+			last DOMAIN;
 			}
 		}
 	}
@@ -613,13 +613,17 @@ elsif ($_[1] eq "PTR") {
 	}
 if ($_[1] eq "A") {
 	print "<tr> <td><b>$text{'edit_uprev'}</b></td>\n";
-	print "<td><input type=radio name=rev value=1 checked> $text{'yes'}\n";
-	print "<input type=radio name=rev value=0> $text{'no'}</td>\n";
+	printf "<td><input type=radio name=rev value=1 %s> $text{'yes'}\n",
+		$config{'rev_def'} ? '' : 'checked';
+	printf "<input type=radio name=rev value=0 %s> $text{'no'}</td>\n",
+		$config{'rev_def'} ? 'checked' : '';
 	}
 elsif ($_[1] eq "PTR") {
 	print "<tr> <td><b>$text{'edit_upfwd'}</b></td>\n";
-	print "<td><input type=radio name=fwd value=1 checked> $text{'yes'}\n";
-	print "<input type=radio name=fwd value=0> $text{'no'}</td>\n";
+	printf "<td><input type=radio name=fwd value=1 %s> $text{'yes'}\n",
+		$config{'rev_def'} ? '' : 'checked';
+	printf "<input type=radio name=fwd value=0 %s> $text{'no'}</td>\n",
+		$config{'rev_def'} ? 'checked' : '';
 	}
 else { print "<tr> <td colspan=2></td>\n"; }
 print "<td colspan=2 align=right>\n";
@@ -635,6 +639,21 @@ if (!$a{'ro'}) {
 print "</td></tr></table></td></tr></table></form>\n";
 }
 
+sub zones_table
+{
+local($i);
+print "<table border width=100%>\n";
+print "<tr $tb> <td><b>$text{'index_zone'}</b></td> ",
+      "<td><b>$text{'index_type'}</b></td> </tr>\n";
+for($i=0; $i<@{$_[0]}; $i++) {
+	print "<tr $cb>\n";
+	print "<td><a href=\"$_[0]->[$i]\">$_[1]->[$i]</a></td>\n";
+	print "<td>$_[2]->[$i]</td>\n";
+	print "</tr>\n";
+	}
+print "</table>\n";
+}
+
 @cat_list = ( 'default', 'config', 'parser', 'queries',
 	      'lame-servers', 'statistics', 'panic', 'update',
 	      'ncache', 'xfer-in', 'xfer-out', 'db',
