@@ -128,6 +128,7 @@ else {
 			local @st = stat($1);
 			if ($st[1] != $cdstat[1]) {
 				local $disk = { 'device' => $1,
+						'prefix' => $1,
 						'heads' => $2,
 						'sectors' => $3,
 						'cylinders' => $4,
@@ -156,8 +157,8 @@ local $idx = 0;
 &wait_for($fh, 'System\r');
 while(1) {
 	$wf = &wait_for($fh,
-	  '\n(\/dev\/\S+(\d+))[ \t*]+\d+\s+(\d+)\s+(\d+)\s+(\S+)\s+(\S{1,2})\s+(.*)\r',
-	  '\n(\/dev\/\S+(\d+))[ \t*]+(\d+)\s+(\d+)\s+(\S+)\s+(\S{1,2})\s+(.*)\r');
+	  '\n(\/dev\/\S+?(\d+))[ \t*]+\d+\s+(\d+)\s+(\d+)\s+(\S+)\s+(\S{1,2})\s+(.*)\r',
+	  '\n(\/dev\/\S+?(\d+))[ \t*]+(\d+)\s+(\d+)\s+(\S+)\s+(\S{1,2})\s+(.*)\r');
 	last if ($wf < 0);
 	$matches[4] =~ s/\+$//g;
 	push(@rv, { 'number' => $matches[2],
@@ -447,16 +448,19 @@ return $un =~ /^2\.0\./ || $un =~ /^1\./ || $un =~ /^0\./;
 # Returns an array of  directory, type, mounted
 sub device_status
 {
-local ($mounted) = grep { $_->[1] eq $_[0] }
-		        &foreign_call("mount", "list_mounted");
-local ($mount) = grep { $_->[1] eq $_[0] }
-		      &foreign_call("mount", "list_mounts");
+@mounted = &foreign_call("mount", "list_mounted") if (!@mounted);
+@mounts = &foreign_call("mount", "list_mounts") if (!@mounts);
+$raidconf = &foreign_call("raid", "get_raidtab") if (!$raidconf);
 
-if ($mounted) { return ($mounted->[0], $mounted->[2], 1); }
-elsif ($mount) { return ($mount->[0], $mount->[2], 0); }
+local ($mounted) = grep { $_->[1] eq $_[0] } @mounted;
+local ($mount) = grep { $_->[1] eq $_[0] } @mounts;
+if ($mounted) { return ($mounted->[0], $mounted->[2], 1,
+			&indexof($mount, @mounts),
+			&indexof($mounted, @mounted)); }
+elsif ($mount) { return ($mount->[0], $mount->[2], 0,
+			 &indexof($mount, @mounts)); }
 else {
-	local $conf = &foreign_call("raid", "get_raidtab");
-	foreach $c (@$conf) {
+	foreach $c (@$raidconf) {
 		if (&indexof($_[0], @{$c->{'device'}})) {
 			return ( $c->{'value'}, "raid", 1 );
 			}
@@ -526,10 +530,7 @@ foreach $d (@dlist) {
 		local @parts = &list_partitions($dev);
 		foreach $p (@parts) {
 			next if ($p->{'extended'});
-			local $name = &text('select_part', uc($d->{'type'}),
-					    uc(substr($dev, -1)),
-					    $p->{'number'});
-			$name = $p->{'desc'};
+			local $name = $p->{'desc'};
 			$name .= " (".&tag_name($p->{'type'}).")"
 				if (&tag_name($p->{'type'}));
 			$rv .= sprintf "<option %s value=%s>%s\n",
