@@ -273,7 +273,7 @@ public class FileManager extends Applet
 		if (f.type == 0 || f.type > 4)
 			new ErrorWindow(text("view_enormal"));
 		else
-			show_file(f);
+			show_file(f, false);
 		}
 	else if (b == open_b) {
 		// Open the selected directory
@@ -321,74 +321,19 @@ public class FileManager extends Applet
 			return;
 			}
 
-
 		// Check for an existing file
 		RemoteFile already = showing_files.find(cut_name);
 		String sp = showing_files.path;
 		String dest_path = sp.equals("/") ? sp+cut_name
 						  : sp+"/"+cut_name;
-		if (already != null &&
-		    (already.type == 0 || already.type == 5)) {
-			new ErrorWindow(text("paste_eover", dest_path));
+		if (already != null) {
+			// File exists .. offer to rename
+			new OverwriteWindow(this, already, cut_file);
 			return;
 			}
-		if (already == cut_file) {
-			new ErrorWindow(text("paste_eself"));
-			return;
-			}
-
-		// Move or copy the actual file
-		String[] rv = get_text((cut_mode ? "move.cgi" : "copy.cgi")+
-				       "?from="+urlize(cut_buffer)+
-				       "&to="+urlize(dest_path));
-		if (rv[0].length() > 0) {
-			new ErrorWindow(text(
-				cut_mode ? "paste_emfailed"
-					 : "paste_ecfailed", rv[0]));
-			return;
-			}
-		RemoteFile file = new RemoteFile(this, rv[1], showing_files);
-		if (already == null) {
-			// Add to the parent directory
-			showing_files.add(file);
-			}
-		else {
-			// Update the existing file
-			already.type = file.type;
-			already.user = file.user;
-			already.group = file.group;
-			already.size = file.size;
-			already.perms = file.perms;
-			already.modified = file.modified;
-			file = already;
-			}
-		if (cut_mode) {
-			// Delete the old file
-			cut_par.delete(cut_file);
-			}
-		if (cut_file.type == 0) {
-			// Moving or copying a directory.. update the tree
-			FileNode dest_par_node =
-				(FileNode)nodemap.get(showing_files);
-			dest_par_node.add(new FileNode(file));
-			if (cut_mode) {
-				FileNode cut_par_node =
-					(FileNode)nodemap.get(cut_par);
-				FileNode cut_file_node =
-					(FileNode)nodemap.get(cut_file);
-				if (cut_par_node != null &&
-				    cut_file_node != null)
-					cut_par_node.ch.removeElement(
-								cut_file_node);
-				}
-			dirs.redraw();
-			}
-		show_files(showing_files);
-		if (cut_mode) {
-			// Paste from the destination path from now on
-			cut_mode = false;
-			cut_buffer = dest_path;
-			}
+		
+		// do the move or copy
+		paste_file(cut_file, showing_files, dest_path, null);
 		}
 	else if (b == delete_b) {
 		// Delete the selected file
@@ -528,16 +473,26 @@ public class FileManager extends Applet
 		}
 	else if (d.type <= 4) {
 		// Direct the browser to this file
-		show_file(d);
+		show_file(d, list.last_event.shiftDown());
 		}
 	}
 
-	void show_file(RemoteFile f)
+	void show_file(RemoteFile f, boolean download)
 	{
 	try {
-		URL u = new URL(getDocumentBase(), "show.cgi"+urlize(f.path)+
-				"?rand="+System.currentTimeMillis());
-		getAppletContext().showDocument(u, "show");
+		if (download) {
+			URL u = new URL(getDocumentBase(),
+					"show.cgi"+urlize(f.path)+
+					"?rand="+System.currentTimeMillis()+
+					"&type=application%2Foctet%2Dstream");
+			getAppletContext().showDocument(u);
+			}
+		else {
+			URL u = new URL(getDocumentBase(),
+					"show.cgi"+urlize(f.path)+
+					"?rand="+System.currentTimeMillis());
+			getAppletContext().showDocument(u, "show");
+			}
 		}
 	catch(Exception e) { }
 	}
@@ -547,7 +502,8 @@ public class FileManager extends Applet
 	StringBuffer rv = new StringBuffer();
 	for(int i=0; i<s.length(); i++) {
 		char c = s.charAt(i);
-		if (c == '%' || c == '+' || c == '&' || c == '?' || c == ' ')
+		if (c == '%' || c == '+' || c == '&' || c == '?' || c == ' ' ||
+		    c == '#' || c == '<' || c == '>')
 			rv.append("%"+Integer.toString(c, 16));
 		else
 			rv.append(c);
@@ -597,6 +553,64 @@ public class FileManager extends Applet
 	String p[] = { p1, p2 };
 	return text(k, p);
 	}
+
+	void paste_file(RemoteFile src, RemoteFile dir,
+			String dest, RemoteFile already)
+	{
+	// Move or copy the actual file
+	String[] rv = get_text((cut_mode ? "move.cgi" : "copy.cgi")+
+			       "?from="+urlize(cut_buffer)+
+			       "&to="+urlize(dest));
+	if (rv[0].length() > 0) {
+		new ErrorWindow(text(
+			cut_mode ? "paste_emfailed"
+				 : "paste_ecfailed", rv[0]));
+		return;
+		}
+	RemoteFile file = new RemoteFile(this, rv[1], dir);
+	if (already == null) {
+		// Add to the parent directory
+		dir.add(file);
+		}
+	else {
+		// Update the existing file
+		already.type = file.type;
+		already.user = file.user;
+		already.group = file.group;
+		already.size = file.size;
+		already.perms = file.perms;
+		already.modified = file.modified;
+		file = already;
+		}
+	if (cut_mode) {
+		// Delete the old file
+		src.directory.delete(src);
+		}
+	if (src.type == 0) {
+		// Moving or copying a directory.. update the tree
+		FileNode dest_par_node =
+			(FileNode)nodemap.get(showing_files);
+		dest_par_node.add(new FileNode(file));
+		if (cut_mode) {
+			FileNode cut_par_node =
+				(FileNode)nodemap.get(src.directory);
+			FileNode cut_file_node =
+				(FileNode)nodemap.get(src);
+			if (cut_par_node != null &&
+			    cut_file_node != null)
+				cut_par_node.ch.removeElement(
+							cut_file_node);
+			}
+		dirs.redraw();
+		}
+	show_files(showing_files);
+	if (cut_mode) {
+		// Paste from the destination path from now on
+		cut_mode = false;
+		cut_buffer = dest;
+		}
+
+	}
 }
 
 // A node in the directory tree
@@ -1416,7 +1430,12 @@ class MultiLabel extends BorderPanel
 {
 	public MultiLabel(String s, int max)
 	{
-	super(1);
+	this(s, max, 1);
+	}
+
+	public MultiLabel(String s, int max, int b)
+	{
+	super(b);
 	Vector v = new Vector();
 	StringTokenizer tok = new StringTokenizer(s.trim(), " \t");
 	String line = null;
@@ -1433,3 +1452,60 @@ class MultiLabel extends BorderPanel
 		add(new Label((String)v.elementAt(i), Label.CENTER));
 	}
 }
+
+class OverwriteWindow extends FixedFrame implements CbButtonCallback
+{
+	FileManager filemgr;
+	RemoteFile src, already;
+	TextField newname;
+	CbButton ok, cancel;
+
+	OverwriteWindow(FileManager p, RemoteFile a, RemoteFile s)
+	{
+	filemgr = p; src = s; already = a;
+	setLayout(new BorderLayout());
+	setTitle(filemgr.text("over_title"));
+	add("North",
+	    new MultiLabel(filemgr.text("over_msg", already.path), 30, 0));
+	add("West", new Label(filemgr.text("over_new")));
+	add("East", newname = new TextField(a.name, 30));
+
+	Panel bot = new Panel();
+	bot.setLayout(new FlowLayout(FlowLayout.RIGHT));
+	bot.add(ok = new CbButton(filemgr.get_image("save.gif"),
+				  filemgr.text("over_ok"),
+				  CbButton.LEFT, this));
+	bot.add(cancel = new CbButton(filemgr.get_image("cancel.gif"),
+				  filemgr.text("cancel"),
+				  CbButton.LEFT, this));
+	add("South", bot);
+	pack();
+	show();
+	}
+
+	public void click(CbButton b)
+	{
+	if (b == cancel)
+		dispose();
+	else if (b == ok && newname.getText().length() > 0) {
+		// paste the file, but with a new name
+		RemoteFile ap = already.directory;
+		RemoteFile newalready = ap.find(newname.getText());
+		if (newalready == src) {
+			new ErrorWindow(filemgr.text("paste_eself"));
+			return;
+			}
+		if (newalready != null && (newalready.type == 0 ||
+					   newalready.type == 5)) {
+			new ErrorWindow(
+				filemgr.text("paste_eover", newalready.path));
+			return;
+			}
+		String dpath = (ap.path.equals("/") ? "/" :
+				ap.path+"/")+newname.getText();
+		filemgr.paste_file(src, already.directory, dpath, newalready);
+		dispose();
+		}
+	}
+}
+
