@@ -316,8 +316,8 @@ sub save_select
 sub multi_input
 {
 local $v = &find_value($_[0], $_[2]);
-local $rv = "<tr> <td valign=top><b>$_[1]</b></td> <td colspan=3>".
-	    "<textarea rows=4 cols=80 name=$_[0]>\n$v</textarea></td> </tr>\n";
+local $rv = "<td valign=top><b>$_[1]</b></td> <td colspan=3>".
+	    "<textarea rows=4 cols=80 name=$_[0]>\n$v</textarea></td>\n";
 return $rv;
 }
 
