@@ -83,12 +83,15 @@ $user_homedir = (getpwuid($<))[7];
 if ($config{'userfile'}) {
 	open(USERS, $config{'userfile'});
 	while(<USERS>) {
-		if (/^([^:\s]+):([^:\s]+):(\d*):(.*)/) {
-			$users{$1} = $2;
-			$certs{$1} = $4;
+		s/\r|\n//g;
+		local @user = split(/:/, $_);
+		$users{$user[0]} = $user[1];
+		$certs{$user[0]} = $user[3] if ($user[3]);
+		if ($user[4] =~ /^allow\s+(.*)/) {
+			$allow{$user[0]} = [ &to_ipaddress(split(/\s+/, $1)) ];
 			}
-		elsif (/^([^:\s]+):([^:\s]+)/) {
-			$users{$1} = $2;
+		elsif ($user[4] =~ /^deny\s+(.*)/) {
+			$deny{$user[0]} = [ &to_ipaddress(split(/\s+/, $1)) ];
 			}
 		}
 	close(USERS);
@@ -125,6 +128,79 @@ foreach $k (keys %config) {
 	if ($k !~ /^addtype_(.*)$/) { next; }
 	$mime{$1} = $config{$k};
 	}
+	
+# get the time zone
+if ($config{'log'}) {
+	local(@gmt, @lct, $days, $hours, $mins);
+	@make_date_marr = ("Jan", "Feb", "Mar", "Apr", "May", "Jun",
+		 	   "Jul", "Aug", "Sep", "Oct", "Nov", "Dec");
+	@gmt = gmtime(time());
+	@lct = localtime(time());
+	$days = $lct[3] - $gmt[3];
+	$hours = ($days < -1 ? 24 : 1 < $days ? -24 : $days * 24) +
+		 $lct[2] - $gmt[2];
+	$mins = $hours * 60 + $lct[1] - $gmt[1];
+	$timezone = ($mins < 0 ? "-" : "+"); $mins = abs($mins);
+	$timezone .= sprintf "%2.2d%2.2d", $mins/60, $mins%60;
+	}
+
+if ($config{'inetd'}) {
+	# We are being run from inetd - go direct to handling the request
+	$SIG{'TERM'} = 'DEFAULT';
+	$SIG{'PIPE'} = 'DEFAULT';
+	$SIG{'HUP'} = 'IGNORE';
+	open(SOCK, "+>&STDIN");
+
+	# Check if it is time for the logfile to be cleared
+	if ($config{'logclear'}) {
+		$write_logtime = 0;
+		if (open(LOGTIME, "$config{'logfile'}.time")) {
+			<LOGTIME> =~ /(\d+)/;
+			close(LOGTIME);
+			if ($1 && $1+$config{'logtime'}*60*60 < time()){
+				# need to clear log
+				$write_logtime = 1;
+				unlink($config{'logfile'});
+				}
+			}
+		else { $write_logtime = 1; }
+		if ($write_logtime) {
+			open(LOGTIME, ">$config{'logfile'}.time");
+			print LOGTIME time(),"\n";
+			close(LOGTIME);
+			}
+		}
+
+	# Initialize SSL for this connection
+	if ($use_ssl) {
+		$ssl_con = Net::SSLeay::new($ssl_ctx);
+		Net::SSLeay::set_fd($ssl_con, fileno(SOCK));
+		Net::SSLeay::use_RSAPrivateKey_file(
+			$ssl_con, $config{'keyfile'},
+			&Net::SSLeay::FILETYPE_PEM);
+		Net::SSLeay::use_certificate_file(
+			$ssl_con, $config{'keyfile'},
+			&Net::SSLeay::FILETYPE_PEM);
+		Net::SSLeay::accept($ssl_con) || exit;
+		}
+
+	# Work out the hostname for this web server
+	if (!$config{'host'}) {
+		($myport, $myaddr) =
+			unpack_sockaddr_in(getsockname(SOCK));
+		$myname = gethostbyaddr($myaddr, AF_INET);
+		if ($myname eq "") {
+			$myname = inet_ntoa($myaddr);
+			}
+		$host = $myname;
+		}
+	else { $host = $config{'host'}; }
+	$port = $config{'port'};
+
+	while(&handle_request(getpeername(SOCK))) { }
+	close(SOCK);
+	exit;
+	}
 
 # Open main socket
 $proto = getprotobyname('tcp');
@@ -187,23 +263,7 @@ if ($config{'logclear'}) {
 	push(@childpids, $logclearer);
 	}
 
-# get the time zone
-if ($config{'log'}) {
-	local(@gmt, @lct, $days, $hours, $mins);
-	@make_date_marr = ("Jan", "Feb", "Mar", "Apr", "May", "Jun",
-		 	   "Jul", "Aug", "Sep", "Oct", "Nov", "Dec");
-	@gmt = gmtime(time());
-	@lct = localtime(time());
-	$days = $lct[3] - $gmt[3];
-	$hours = ($days < -1 ? 24 : 1 < $days ? -24 : $days * 24) +
-		 $lct[2] - $gmt[2];
-	$mins = $hours * 60 + $lct[1] - $gmt[1];
-	$timezone = ($mins < 0 ? "-" : "+"); $mins = abs($mins);
-	$timezone .= sprintf "%2.2d%2.2d", $mins/60, $mins%60;
-	}
-
 # Run the main loop
-$SIG{'CHLD'} = 'miniserv::reaper';
 $SIG{'HUP'} = 'miniserv::trigger_restart';
 $SIG{'TERM'} = 'miniserv::term_handler';
 $SIG{'PIPE'} = 'IGNORE';
@@ -221,12 +281,36 @@ while(1) {
 		}
 	vec($rmask, fileno(LISTEN), 1) = 1 if ($config{'listen'});
 
-	local $sel = select($rmask, undef, undef, undef);
+	local $sel = select($rmask, undef, undef, 10);
 	if ($need_restart) { &restart_miniserv(); }
+
+	# Clean up finished processes
+	local($pid);
+	do {	$pid = waitpid(-1, WNOHANG);
+		@childpids = grep { $_ != $pid } @childpids;
+		} while($pid > 0);
+
 	next if ($sel <= 0);
 	if (vec($rmask, fileno(MAIN), 1)) {
 		# got new connection
 		$acptaddr = accept(SOCK, MAIN);
+
+		# run the unblocking procedure to check if enough time has passed to
+		# unblock hosts that heve been blocked because of password failures
+		if ($config{'blockhost_failures'}) {
+			$i = 0;
+			while ($i <= $#deny) {
+				if ($blockhosttime{$deny[$i]} && $config{'blockhost_time'} != 0 &&
+						(time() - $blockhosttime{$deny[$i]}) >= $config{'blockhost_time'}) {
+					# the host can be unblocked now
+					#print STDERR "unblocking $deny[$i]\n";
+					$hostfail{$deny[$i]} = 0;
+					splice(@deny, $i, 1);
+					}
+				$i++;
+				}
+			}
+		
 		if (!$acptaddr) { next; }
 
 		# create pipes
@@ -239,7 +323,6 @@ while(1) {
 			select($PASSINw); $| = 1;
 			select($PASSOUTw); $| = 1;
 			}
-		select(SOCK); $| = 1;
 		select(STDOUT);
 
 		# fork the subprocess
@@ -301,6 +384,7 @@ while(1) {
 		# Got UDP packet from another webmin server
 		local $rcvbuf;
 		local $from = recv(LISTEN, $rcvbuf, 1024, 0);
+		next if (!$from);
 		local $fromip = inet_ntoa((unpack_sockaddr_in($from))[1]);
 		if ((!@deny || !&ip_match($fromip, @deny)) &&
 		    (!@allow || &ip_match($fromip, @allow))) {
@@ -324,13 +408,25 @@ while(1) {
 				if ($3) {
 					# login OK.. no delay
 					print $outfd "0\n";
+					$hostfail{$2} = 0;
 					}
 				else {
-					# login failed.. 
+					# login failed..
+					$hostfail{$2}++;
+					# add the host to the block list if necessary
+ 					if ($config{'blockhost_failures'} &&
+					    $hostfail{$2} >= $config{'blockhost_failures'}) {
+						push(@deny, $2);					
+						$blockhosttime{$2} = time();
+						$blocked = 1;
+						}
+					else {
+						$blocked = 0;
+						}
 					$dl = $userdlay{$1} -
 					      int((time() - $userlast{$1})/50);
 					$dl = $dl < 0 ? 0 : $dl+1;
-					print $outfd "$dl\n";
+					print $outfd "$dl $blocked\n";
 					$userdlay{$1} = $dl;
 					}
 				$userlast{$1} = time();
@@ -384,7 +480,6 @@ if ($page =~ /^([^\?]+)\?(.*)$/) {
 
 # replace %XX sequences in page
 $page =~ s/%(..)/pack("c",hex($1))/ge;
-
 # check address against access list
 if (@deny && &ip_match($acptip, @deny) ||
     @allow && !&ip_match($acptip, @allow)) {
@@ -407,13 +502,25 @@ if ($config{'logout'} && -r $config{'logout'}) {
 	&write_data("<h1>Please Login</h1>\n");
 	&write_data("Please login to the server as a new user.<p>\n");
 	&log_request($acptip, undef, $reqline, 401, &byte_count());
-	unlink($config{'logout'});
+	open(LOGOUT, $config{'logout'});
+	chop($count = <LOGOUT>);
+	close(LOGOUT);
+	$count--;
+	if ($count > 0) {
+		open(LOGOUT, ">$config{'logout'}");
+		print LOGOUT "$count\n";
+		close(LOGOUT);
+		}
+	else {
+		unlink($config{'logout'});
+		}
 	return 0;
 	}
 
 # Check for password if needed
 if (%users) {
 	$validated = 0;
+	$blocked = 0;
 
 	# check for SSL authentication
 	if ($use_ssl && $verified_client) {
@@ -440,30 +547,47 @@ if (%users) {
 			}
 		#print STDERR "checking $authuser $authpass -> $validated\n";
 
-		if ($config{'passdelay'}) {
+		if ($config{'passdelay'} && !$config{'inetd'}) {
 			# check with main process for delay
 			print $PASSINw "$authuser $acptip $validated\n";
-			<$PASSOUTr> =~ /(\d+)/;
+			<$PASSOUTr> =~ /(\d+) (\d+)/;
 			#print STDERR "sleeping for $1\n";
+			$blocked = $2;
 			sleep($1);
 			}
 		}
 	if (!$validated) {
-		# No password given.. ask
-		&write_data("HTTP/1.0 401 Unauthorized\r\n");
-		&write_data("Server: $config{'server'}\r\n");
-		&write_data("Date: $datestr\r\n");
-		&write_data("WWW-authenticate: Basic ".
-			   "realm=\"$config{'realm'}\"\r\n");
-		&write_data("Content-type: text/html\r\n");
-		&write_keep_alive(0);
-		&write_data("\r\n");
-		&reset_byte_count();
-		&write_data("<title>Unauthorized</title>\n");
-		&write_data("<h1>Unauthorized</h1>\n");
-		&write_data("A password is required to access this\n");
-		&write_data("web server. Please try again. <p>\n");
-		&log_request($acptip, undef, $reqline, 401, &byte_count());
+		if ($blocked == 0) {
+			# No password given.. ask
+			&write_data("HTTP/1.0 401 Unauthorized\r\n");
+			&write_data("Date: $datestr\r\n");
+			&write_data("Server: $config{'server'}\r\n");
+			&write_data("WWW-authenticate: Basic ".
+				   "realm=\"$config{'realm'}\"\r\n");
+			&write_keep_alive(0);
+			&write_data("Content-type: text/html\r\n");
+			&write_data("\r\n");
+			&reset_byte_count();
+			&write_data("<html>\n");
+			&write_data("<head><title>Unauthorized</title></head>\n");
+			&write_data("<body><h1>Unauthorized</h1>\n");
+			&write_data("A password is required to access this\n");
+			&write_data("web server. Please try again. <p>\n");
+			&write_data("</body></html>\n");
+			&log_request($acptip, undef, $reqline, 401, &byte_count());
+			}
+		else {
+			# when the host has been blocked, give it an error message
+			&http_error(403, "Access denied for $acptip. The host has been blocked "
+				."because of too many authentication failures.");
+			}
+		return 0;
+		}
+
+	# Check per-user IP access control
+	if ($deny{$authuser} && &ip_match($acptip, @{$deny{$authuser}}) ||
+	    $allow{$authuser} && !&ip_match($acptip, @{$allow{$authuser}})) {
+		&http_error(403, "Access denied for $acptip");
 		return 0;
 		}
 	}
@@ -618,7 +742,7 @@ if (&get_type($full) eq "internal/cgi") {
 	local $first = <CGI>;
 	close(CGI);
 	$first =~ s/[#!\r\n]//g;
-	if ($first eq $perl_path && $] >= 5.004) {
+	if (!$config{'forkcgis'} && $first eq $perl_path && $] >= 5.004) {
 		# setup environment for eval
 		chdir($ENV{"PWD"});
 		@ARGV = split(/\s+/, $queryargs);
@@ -635,6 +759,11 @@ if (&get_type($full) eq "internal/cgi") {
 				}
 			}
 		$SIG{'CHLD'} = 'DEFAULT';
+		eval {
+			# Have SOCK closed if the perl exec's something
+			use Fcntl;
+			fcntl(SOCK, F_SETFD, FD_CLOEXEC);
+			};
 
 		if ($config{'log'}) {
 			open(MINISERVLOG, ">>$config{'logfile'}");
@@ -654,7 +783,7 @@ if (&get_type($full) eq "internal/cgi") {
 			&http_error(500, "Perl execution failed", $@);
 			}
 		elsif (!$doneheaders) {
-			&http_error(500, "Missing Header");
+			&http_error(500, "Missing Headers");
 			}
 		close(SOCK);
 		$rv = 0;
@@ -716,7 +845,7 @@ if (&get_type($full) eq "internal/cgi") {
 			close(CGIOUTr); close(CGIERRr);
 			}
 		elsif ($cgiheader{"content-type"} eq "") {
-			&http_error(500, "Missing Header",
+			&http_error(500, "Missing Content-Type Header",
 				    &read_errors(CGIERRr));
 			}
 		else {
@@ -952,7 +1081,7 @@ if ($use_ssl) {
 	Net::SSLeay::write($ssl_con, $_[0]);
 	}
 else {
-	print SOCK $_[0];
+	syswrite(SOCK, $_[0], length($_[0]));
 	}
 $write_data_count += length($_[0]);
 }
@@ -963,16 +1092,6 @@ sub reset_byte_count { $write_data_count = 0; }
 # byte_count()
 sub byte_count { return $write_data_count; }
 
-# reaper()
-# Collects dead processes
-sub reaper
-{
-local($pid);
-do {	$pid = waitpid(-1, WNOHANG);
-	@childpids = grep { $_ != $pid } @childpids;
-	} while($pid > 0);
-}
-
 # log_request(address, user, request, code, bytes)
 sub log_request
 {
@@ -1035,14 +1154,14 @@ exit(1);
 sub http_date
 {
 local @tm = gmtime($_[0]);
-return sprintf "%s %d %s %d %2.2d:%2.2d:%2.2d GMT",
+return sprintf "%s, %d %s %d %2.2d:%2.2d:%2.2d GMT",
 		$weekday[$tm[6]], $tm[3], $month[$tm[4]], $tm[5]+1900,
 		$tm[2], $tm[1], $tm[0];
 }
 
 sub TIEHANDLE
 {
-my $i; bless \$i, shift
+my $i; bless \$i, shift;
 }
  
 sub WRITE
@@ -1072,6 +1191,11 @@ $r = shift;
 substr($_[0], $_[2], $_[1]) = substr($postinput, $postpos, $_[1]);
 $postpos += $_[1];
 }
+
+sub OPEN
+{
+print STDERR "open() called - should never happen!\n";
+}
  
 sub READLINE
 {
@@ -1127,7 +1251,7 @@ foreach $d (@_) {
 					"HTTP/1.0 302 Moved Temporarily\r\n");
 				}
 			elsif ($cgiheader{"content-type"} eq "") {
-				&http_error(500, "Missing Header");
+				&http_error(500, "Missing Content-Type Header");
 				}
 			else {
 				&write_data("HTTP/1.0 200 Document follows\r\n");
