@@ -432,59 +432,68 @@ elsif ($_[0] eq "ufs") {
 	# somewhere else
 	print "<tr> <td valign=top><b>$text{'solaris_ufs'}</b></td>\n";
 	print "<td colspan=3>\n";
+	&foreign_require("format", "format-lib.pl");
+
 	if ($_[1] =~ /^\/dev\/dsk\/c([0-9]+)t([0-9]+)d([0-9]+)s([0-9]+)$/) {
 		$ufs_dev = 0;
-		$scsi_c = $1; $scsi_t = $2; $scsi_d = $3; $scsi_s = $4;
 		}
 	elsif ($_[1] eq "") {
-		$ufs_dev = 0; $scsi_c = $scsi_t = $scsi_s = $scsi_d = 0;
+		$ufs_dev = 0;
 		}
 	elsif ($_[1] =~ /^\/dev\/md\/dsk\/d([0-9]+)$/) {
-		$ufs_dev = 1; $scsi_md = $1;
+		$ufs_dev = 1;
 		}
 	else {
-		$ufs_dev = 2; $scsi_path = $_[1];
+		$ufs_dev = 2;
 		}
-	printf "<input type=radio name=ufs_dev value=0 %s> $text{'solaris_scsi'}:\n",
-		$ufs_dev == 0 ? "checked" : "";
-	print "$text{'solaris_ctrlr'} <input name=ufs_c size=3 value=\"$scsi_c\">\n";
-	print "$text{'solaris_target'} <input name=ufs_t size=3 value=\"$scsi_t\">\n";
-	print "$text{'solaris_unit'} <input name=ufs_d size=3 value=\"$scsi_d\">\n";
-	print "$text{'solaris_part'} <input name=ufs_s size=3 value=\"$scsi_s\"><br>\n";
 
-	printf "<input type=radio name=ufs_dev value=1 %s> $text{'solaris_raid'}:\n",
-		$ufs_dev == 1 ? "checked" : "";
-	print "$text{'solaris_unit'} <input name=ufs_md size=3 value=\"$scsi_md\"><br>\n";
+	local $found;
+	local $sel = &foreign_call("format", "partition_select",
+				   "ufs_disk", $_[1], 0,
+				   $ufs_dev ? \$found : undef);
+	printf "<input type=radio name=ufs_dev value=0 %s> %s : %s<br>\n",
+		$ufs_dev == 0 ? "checked" : "", $text{'solaris_scsi'}, $sel;
 
-	printf "<input type=radio name=ufs_dev value=2 %s> $text{'solaris_otherdev'}:\n",
-		$ufs_dev == 2 ? "checked" : "";
-	print "<input name=ufs_path size=20 value=\"$scsi_path\"><br>\n";
+	printf "<input type=radio name=ufs_dev value=1 %s> %s :\n",
+		$ufs_dev == 1 ? "checked" : "",
+		$text{'solaris_raid'};
+	printf "%s <input name=ufs_md size=3 value=\"%s\"><br>\n",
+		$text{'solaris_unit'},
+		 $_[1] =~ /^\/dev\/md\/dsk\/d([0-9]+)$/ ? $1 : "";
+
+	printf "<input type=radio name=ufs_dev value=2 %s> %s :\n",
+		$ufs_dev == 2 ? "checked" : "", $text{'solaris_otherdev'};
+	printf "<input name=ufs_path size=20 value=\"%s\"><br>\n",
+		$ufs_dev == 2 ? $_[1] : "";
 	print "</td> </tr>\n";
 	}
 elsif ($_[0] eq "swap") {
 	# Swapping to a disk partition or a file
 	print "<tr> <td valign=top><b>$text{'solaris_swapfile'}</b></td>\n";
 	print "<td colspan=3>\n";
+	&foreign_require("format", "format-lib.pl");
+
 	if ($_[1] =~ /^\/dev\/dsk\/c([0-9]+)t([0-9]+)d([0-9]+)s([0-9]+)$/) {
 		$swap_dev = 0;
-		$scsi_c = $1; $scsi_t = $2; $scsi_d = $3; $scsi_s = $4;
 		}
 	elsif ($_[1] eq "") {
-		$swap_dev = 1; $scsi_path = "";
+		$swap_dev = 0;
 		}
 	else {
-		$swap_dev = 1; $scsi_path = $_[1];
+		$swap_dev = 1;
 		}
-	printf "<input type=radio name=swap_dev value=0 %s> $text{'solaris_scsi'}:\n",
-		$swap_dev == 0 ? "checked" : "";
-	print "$text{'solaris_ctrlr'} <input name=swap_c size=3 value=\"$scsi_c\">\n";
-	print "$text{'solaris_target'} <input name=swap_t size=3 value=\"$scsi_t\">\n";
-	print "$text{'solaris_unit'} <input name=swap_d size=3 value=\"$scsi_d\">\n";
-	print "$text{'solaris_part'} <input name=swap_s size=3 value=\"$scsi_s\"><br>\n";
 
-	printf "<input type=radio name=swap_dev value=1 %s> $text{'solaris_file'}:\n",
-		$swap_dev == 1 ? "checked" : "";
-	print "<input name=swap_path size=20 value=\"$scsi_path\"><br>\n";
+	local $found;
+	local $sel = &foreign_call("format", "partition_select",
+				   "swap_disk", $_[1], 0,
+				   $swap_dev ? \$found : undef);
+	printf "<input type=radio name=swap_dev value=0 %s> %s : %s<br>\n",
+		$swap_dev == 0 ? "checked" : "", $text{'solaris_scsi'}, $sel;
+
+	printf "<input type=radio name=swap_dev value=1 %s> %s :\n",
+		$swap_dev == 1 ? "checked" : "", $text{'solaris_file'};
+	printf "<input name=swap_path size=20 value=\"%s\"><br>\n",
+		$swap_dev == 1 ? $_[1] : "";
 	print "</td> </tr>\n";
 	}
 elsif ($_[0] eq "hsfs") {
@@ -518,26 +527,29 @@ elsif ($_[0] eq "pcfs") {
 	# Mounting a SCSI msdos filesystem
 	print "<tr> <td valign=top><b>$text{'solaris_msdos'}</b></td>\n";
 	print "<td colspan=3>\n";
+	&foreign_require("format", "format-lib.pl");
+
 	if ($_[1] =~ /^\/dev\/dsk\/c([0-9]+)t([0-9]+)d([0-9]+)s([0-9]+)$/) {
 		$pcfs_dev = 0;
-		$scsi_c = $1; $scsi_t = $2; $scsi_d = $3; $scsi_s = $4;
 		}
 	elsif ($_[1] eq "") {
-		$pcfs_dev = 1; $scsi_path = "";
+		$pcfs_dev = 0;
 		}
 	else {
-		$pcfs_dev = 1; $scsi_path = $_[1];
+		$pcfs_dev = 2;
 		}
-	printf "<input type=radio name=ufs_dev value=0 %s> $text{'solaris_scsi'}:\n",
-		$pcfs_dev == 0 ? "checked" : "";
-	print "$text{'solaris_ctrlr'} <input name=ufs_c size=3 value=\"$scsi_c\">\n";
-	print "$text{'solaris_target'} <input name=ufs_t size=3 value=\"$scsi_t\">\n";
-	print "$text{'solaris_unit'} <input name=ufs_d size=3 value=\"$scsi_d\">\n";
-	print "$text{'solaris_part'} <input name=ufs_s size=3 value=\"$scsi_s\"><br>\n";
 
-	printf "<input type=radio name=ufs_dev value=2 %s> $text{'solaris_otherdev'}:\n",
-		$pcfs_dev == 2 ? "checked" : "";
-	print "<input name=ufs_path size=20 value=\"$scsi_path\"><br>\n";
+	local $found;
+	local $sel = &foreign_call("format", "partition_select",
+				   "ufs_disk", $_[1], 0,
+				   $pcfs_dev ? \$found : undef);
+	printf "<input type=radio name=ufs_dev value=0 %s> %s : %s<br>\n",
+		$pcfs_dev == 0 ? "checked" : "", $text{'solaris_scsi'}, $sel;
+
+	printf "<input type=radio name=ufs_dev value=2 %s> %s :\n",
+		$pcfs_dev == 2 ? "checked" : "", $text{'solaris_file'};
+	printf "<input name=ufs_path size=20 value=\"%s\"><br>\n",
+		$pcfs_dev == 2 ? $_[1] : "";
 	print "</td> </tr>\n";
 	}
 elsif ($_[0] eq "lofs") {
@@ -1051,18 +1063,10 @@ if ($_[0] eq "nfs") {
 	rmdir($temp);
 	return "$in{nfs_host}:$in{nfs_dir}";
 	}
-elsif ($_[0] eq "ufs" || $_[0] eq "pcfs" || $_[0] eq "hsfs") {
+elsif ($_[0] eq "ufs" || $_[0] eq "pcfs") {
 	# Get the device name
 	if ($in{ufs_dev} == 0) {
-		$in{ufs_c} =~ /^[0-9]+$/ ||
-			&error(&text('solaris_ectrlr', $in{'ufs_c'}));
-		$in{ufs_t} =~ /^[0-9]+$/ ||
-			&error(&text('solaris_etarget', $in{'ufs_t'}));
-		$in{ufs_d} =~ /^[0-9]+$/ ||
-			&error(&text('solaris_eunit', $in{'ufs_d'}));
-		$in{ufs_s} =~ /^[0-9]+$/ ||
-			&error(&text('solaris_epart', $in{'ufs_s'}));
-		$dv = "/dev/dsk/c$in{ufs_c}t$in{ufs_t}d$in{ufs_d}s$in{ufs_s}";
+		$dv = $in{'ufs_disk'};
 		}
 	elsif ($in{ufs_dev} == 1) {
 		$in{ufs_md} =~ /^[0-9]+$/ ||
@@ -1076,6 +1080,27 @@ elsif ($_[0] eq "ufs" || $_[0] eq "pcfs" || $_[0] eq "hsfs") {
 		}
 
 	&fstyp_check($dv, $_[0]);
+	return $dv;
+	}
+elsif ($_[0] eq "hsfs") {
+	# Get the device name
+	if ($in{ufs_dev} == 0) {
+		$in{ufs_c} =~ /^[0-9]+$/ ||
+			&error(&text('solaris_ectrlr', $in{'ufs_c'}));
+		$in{ufs_t} =~ /^[0-9]+$/ ||
+			&error(&text('solaris_etarget', $in{'ufs_t'}));
+		$in{ufs_d} =~ /^[0-9]+$/ ||
+			&error(&text('solaris_eunit', $in{'ufs_d'}));
+		$in{ufs_s} =~ /^[0-9]+$/ ||
+			&error(&text('solaris_epart', $in{'ufs_s'}));
+		$dv = "/dev/dsk/c$in{ufs_c}t$in{ufs_t}d$in{ufs_d}s$in{ufs_s}";
+		}
+	else {
+		$in{ufs_path} =~ /^\/\S+$/ ||
+			&error(&text('solaris_epath', $in{'ufs_path'}));
+		$dv = $in{ufs_path};
+		}
+
 	return $dv;
 	}
 elsif ($_[0] eq "lofs") {
@@ -1087,15 +1112,7 @@ elsif ($_[0] eq "lofs") {
 	}
 elsif ($_[0] eq "swap") {
 	if ($in{swap_dev} == 0) {
-		$in{swap_c} =~ /^[0-9]+$/ ||
-			&error(&text('solaris_ectrlr', $in{'swap_c'}));
-		$in{swap_t} =~ /^[0-9]+$/ ||
-			&error(&text('solaris_etarget', $in{'swap_t'}));
-		$in{swap_d} =~ /^[0-9]+$/ ||
-			&error(&text('solaris_eunit', $in{'swap_d'}));
-		$in{swap_s} =~ /^[0-9]+$/ ||
-			&error(&text('solaris_epart', $in{'swap_s'}));
-		$dv="/dev/dsk/c$in{swap_c}t$in{swap_t}d$in{swap_d}s$in{swap_s}";
+		$dv = $in{'swap_disk'};
 		}
 	else { $dv = $in{swap_path}; }
 
