@@ -42,9 +42,14 @@ unlink("$module_config_directory/$_[0].serv");
 		  [ 'redhat', 'Redhat Linux' ],
 		  [ 'suse', 'SuSE Linux' ],
 		  [ 'debian', 'Debian Linux' ],
+		  [ 'mandrake', 'Mandrake Linux' ],
 		  [ 'linux', 'Linux' ],
 		  [ 'freebsd', 'FreeBSD' ],
 		  [ 'solaris', 'Solaris' ],
+		  [ 'hpux', 'HP/UX' ],
+		  [ 'sco', 'SCO' ],
+		  [ 'mac', 'Macintosh' ],
+		  [ 'irix', 'IRIX' ],
 		  [ 'unknown', 'Other' ] );
 
 
