@@ -101,6 +101,9 @@ if [ "$upgrading" = 1 ]; then
 	# Check for third-party modules in old version
 	if [ "$wadir" != "$oldwadir" ]; then
 		echo "Checking for third-party modules .."
+		if [ "$webmin_upgrade" != "" ]; then
+			autothird=1
+		fi
 		$perl $wadir/thirdparty.pl $wadir $oldwadir $autothird
 		echo "..done"
 		echo ""
