@@ -1,4 +1,4 @@
-#!/usr/bin/perl
+#!/usr/local/bin/perl
 
 do "../web-lib.pl";
 
@@ -43,7 +43,7 @@ sub p_select_wdl
 
   do
   {
-	$out .= "<option name=$name value=$list[$i++]";
+	$out .= "<option value=$list[$i++]";
 	$out .= " selected" if( $selected eq $list[$i] );
 	$out .= ">$list[$i++]";
   } while( $i < $size );
