@@ -10,7 +10,7 @@ $config_directory = $ENV{'WEBMIN_CONFIG'};
 if (!defined($ENV{'WEBMIN_VAR'})) { die "WEBMIN_VAR not set"; }
 $var_directory = $ENV{'WEBMIN_VAR'};
 
-# read_file(file, &assoc, [&order])
+# read_file(file, &assoc, [&order], [lowercase])
 # Fill an associative array with name=value pairs from a file
 sub read_file
 {
@@ -18,8 +18,8 @@ open(ARFILE, $_[0]) || return 0;
 while(<ARFILE>) {
 	s/\r|\n//g;
         if (!/^#/ && /^([^=]+)=(.*)$/) {
-		$_[1]->{$1} = $2;
-		push(@{$_[2]}, $1);
+		$_[1]->{$_[3] ? lc($1) : $1} = $2;
+		push(@{$_[2]}, $1) if ($_[2]);
         	}
         }
 close(ARFILE);
@@ -96,8 +96,18 @@ return 0;
 # Returns a mostly random temporary file name
 sub tempname
 {
+while(1) {
+	local @st = lstat("/tmp/.webmin");
+	last if (!$st[4] && !$st[5] && $st[2] & 0x4000 &&
+		 ($st[2] & 0777) == 0755);
+	if (@st) {
+		unlink("/tmp/.webmin") || system("rm -rf /tmp/.webmin");
+		}
+	mkdir("/tmp/.webmin", 0755) || next;
+	chown(0, 0, "/tmp/.webmin");
+	}
 $tempfilecount++;
-return "/tmp/".$$."_".$tempfilecount."_".$scriptname;
+return "/tmp/.webmin/".$$."_".$tempfilecount."_".$scriptname;
 }
 
 # trunc
@@ -450,13 +460,14 @@ $whatfailed = $_[0];
 sub wait_for
 {
 local($hit, $c, $i, $sw, $rv, $ha); undef($wait_for_input);
+#print STDERR "wait_for(",join(",", @_),")\n";
 $ha = $_[0];
 $code =
 "undef(\$hit);\n".
 "while(1) {\n".
 " if ((\$c = getc($ha)) eq \"\") { return -1; }\n".
 " \$wait_for_input .= \$c;\n";
-#" \$wait_for_input .= \$c;\nprint \$wait_for_input,\"\\n\";";
+#" \$wait_for_input .= \$c;\nprint STDERR \$wait_for_input,\"\\n\";";
 for($i=1; $i<@_; $i++) {
         $sw = $i>1 ? "elsif" : "if";
         $code .= " $sw (\$wait_for_input =~ /$_[$i]/i) { \$hit = $i-1; }\n";
@@ -584,6 +595,7 @@ sub restart_miniserv
 {
 local($pid, %miniserv, $addr, $i);
 &get_miniserv_config(\%miniserv) || return;
+$miniserv{'inetd'} && return;
 open(PID, $miniserv{'pidfile'}) || &error("Failed to open pid file");
 chop($pid = <PID>);
 close(PID);
@@ -842,6 +854,7 @@ foreach $f (keys %file_cache) {
                 }
         close(FLUSHFILE);               
         }                               
+undef(%file_cache);
 }                                       
 
 # unix_user_input(fieldname, user)
@@ -1048,6 +1061,37 @@ if ($module_name && !$main::no_acl_check && !$ENV{'FOREIGN_MODULE_NAME'}) {
 		       "use the <i>$minfo{'desc'}</i> module");
 	$main::no_acl_check++;
 	}
+
+# Check the Referer: header for nasty redirects
+if ($0 && $0 !~ /index\.cgi$/ && $0 !~ /referer_save\.cgi$/ &&
+    !$gconfig{'referer'} &&
+    $ENV{'MINISERV_CONFIG'} &&
+    $ENV{'HTTP_REFERER'} =~ /^http:\/\/([^\/]+)\// &&
+    $1 ne $ENV{'HTTP_HOST'}) {
+	# Looks like a link from elsewhere ..
+	&header($text{'referer_title'}, "");
+	print "<hr><center>\n";
+	print "<form action=/referer_save.cgi>\n";
+	&ReadParse();
+	foreach $k (keys %in) {
+		foreach $kk (split(/\0/, $in{$k})) {
+			print "<input type=hidden name=$k value='$kk'>\n";
+			}
+		}
+	print "<input type=hidden name=referer_original ",
+	      "value='$ENV{'REQUEST_URI'}'>\n";
+
+	$prot = lc($ENV{'HTTPS'}) eq 'on' ? "https" : "http";
+	print "<p>",&text('referer_warn', "<tt>$ENV{'HTTP_REFERER'}</tt>",
+	      "<tt>$prot://$ENV{'HTTP_HOST'}$ENV{'REQUEST_URI'}</tt>"),"<p>\n";
+	print "<input type=submit value='$text{'referer_ok'}'><br>\n";
+	print "<input type=checkbox name=referer_again value=1> ",
+	      "$text{'referer_again'}<p>\n";
+	print "</form></center><hr>\n";
+	&footer("/", $text{'index'});
+	exit;
+	}
+
 return 1;
 }
 
@@ -1057,14 +1101,22 @@ $default_lang = "en";
 # Returns a hashtable mapping text codes to strings in the appropriate language
 sub load_language
 {
-local $mod = $_[0] ? "../$_[0]" : ".";
 local %text;
 if ($module_name) {
+	local $mod = $_[0] ? "../$_[0]" : ".";
 	&read_file("../lang/$default_lang", \%text);
 	&read_file("../lang/$current_lang", \%text);
+	&read_file("$mod/lang/$default_lang", \%text);
+	&read_file("$mod/lang/$current_lang", \%text);
+	}
+else {
+	&read_file("lang/$default_lang", \%text);
+	&read_file("lang/$current_lang", \%text);
+	if ($_[0]) {
+		&read_file("$_[0]/lang/$default_lang", \%text);
+		&read_file("$_[0]/lang/$current_lang", \%text);
+		}
 	}
-&read_file("$mod/lang/$default_lang", \%text);
-&read_file("$mod/lang/$current_lang", \%text);
 return %text;
 }
 
@@ -1175,5 +1227,17 @@ foreach $k (keys %{$_[1]}) {
 close(FILE);
 }
 
+# lock_file(filename)
+# Wait until a lock is obtained on the given file
+sub lock_file
+{
+}
+
+# unlock_file(filename)
+# Release a lock grabbed by lock_file()
+sub unlock_file
+{
+}
+
 1;  # return true?
 
